from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.TopAbs import *
from OCC.Core.TCollection import *
from OCC.Core.TopOpeBRepTool import *
from OCC.Core.TopoDS import *
from OCC.Core.Geom2d import *
from OCC.Core.TopTools import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *

#the following typedef cannot be wrapped as is
TopOpeBRepDS_DoubleMapIteratorOfDoubleMapOfIntegerShape = NewType('TopOpeBRepDS_DoubleMapIteratorOfDoubleMapOfIntegerShape', Any)
#the following typedef cannot be wrapped as is
TopOpeBRepDS_DoubleMapOfIntegerShape = NewType('TopOpeBRepDS_DoubleMapOfIntegerShape', Any)
#the following typedef cannot be wrapped as is
TopOpeBRepDS_IndexedDataMapOfShapeWithState = NewType('TopOpeBRepDS_IndexedDataMapOfShapeWithState', Any)
#the following typedef cannot be wrapped as is
TopOpeBRepDS_IndexedDataMapOfVertexPoint = NewType('TopOpeBRepDS_IndexedDataMapOfVertexPoint', Any)
#the following typedef cannot be wrapped as is
TopOpeBRepDS_MapOfShapeData = NewType('TopOpeBRepDS_MapOfShapeData', Any)
TopOpeBRepDS_PDataStructure = NewType('TopOpeBRepDS_PDataStructure', TopOpeBRepDS_DataStructure)

class TopOpeBRepDS_Array1OfDataMapOfIntegerListOfInterference:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> TopOpeBRepDS_DataMapOfIntegerListOfInterference: ...
    def __setitem__(self, index: int, value: TopOpeBRepDS_DataMapOfIntegerListOfInterference) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[TopOpeBRepDS_DataMapOfIntegerListOfInterference]: ...
    def next(self) -> TopOpeBRepDS_DataMapOfIntegerListOfInterference: ...
    __next__ = next
    def Init(self, theValue: TopOpeBRepDS_DataMapOfIntegerListOfInterference) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> TopOpeBRepDS_DataMapOfIntegerListOfInterference: ...
    def Last(self) -> TopOpeBRepDS_DataMapOfIntegerListOfInterference: ...
    def Value(self, theIndex: int) -> TopOpeBRepDS_DataMapOfIntegerListOfInterference: ...
    def SetValue(self, theIndex: int, theValue: TopOpeBRepDS_DataMapOfIntegerListOfInterference) -> None: ...

class TopOpeBRepDS_ListOfInterference:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TopOpeBRepDS_Config(IntEnum):
	TopOpeBRepDS_UNSHGEOMETRY: int = ...
	TopOpeBRepDS_SAMEORIENTED: int = ...
	TopOpeBRepDS_DIFFORIENTED: int = ...
TopOpeBRepDS_UNSHGEOMETRY = TopOpeBRepDS_Config.TopOpeBRepDS_UNSHGEOMETRY
TopOpeBRepDS_SAMEORIENTED = TopOpeBRepDS_Config.TopOpeBRepDS_SAMEORIENTED
TopOpeBRepDS_DIFFORIENTED = TopOpeBRepDS_Config.TopOpeBRepDS_DIFFORIENTED

class TopOpeBRepDS_CheckStatus(IntEnum):
	TopOpeBRepDS_OK: int = ...
	TopOpeBRepDS_NOK: int = ...
TopOpeBRepDS_OK = TopOpeBRepDS_CheckStatus.TopOpeBRepDS_OK
TopOpeBRepDS_NOK = TopOpeBRepDS_CheckStatus.TopOpeBRepDS_NOK

class TopOpeBRepDS_Kind(IntEnum):
	TopOpeBRepDS_POINT: int = ...
	TopOpeBRepDS_CURVE: int = ...
	TopOpeBRepDS_SURFACE: int = ...
	TopOpeBRepDS_VERTEX: int = ...
	TopOpeBRepDS_EDGE: int = ...
	TopOpeBRepDS_WIRE: int = ...
	TopOpeBRepDS_FACE: int = ...
	TopOpeBRepDS_SHELL: int = ...
	TopOpeBRepDS_SOLID: int = ...
	TopOpeBRepDS_COMPSOLID: int = ...
	TopOpeBRepDS_COMPOUND: int = ...
	TopOpeBRepDS_UNKNOWN: int = ...
TopOpeBRepDS_POINT = TopOpeBRepDS_Kind.TopOpeBRepDS_POINT
TopOpeBRepDS_CURVE = TopOpeBRepDS_Kind.TopOpeBRepDS_CURVE
TopOpeBRepDS_SURFACE = TopOpeBRepDS_Kind.TopOpeBRepDS_SURFACE
TopOpeBRepDS_VERTEX = TopOpeBRepDS_Kind.TopOpeBRepDS_VERTEX
TopOpeBRepDS_EDGE = TopOpeBRepDS_Kind.TopOpeBRepDS_EDGE
TopOpeBRepDS_WIRE = TopOpeBRepDS_Kind.TopOpeBRepDS_WIRE
TopOpeBRepDS_FACE = TopOpeBRepDS_Kind.TopOpeBRepDS_FACE
TopOpeBRepDS_SHELL = TopOpeBRepDS_Kind.TopOpeBRepDS_SHELL
TopOpeBRepDS_SOLID = TopOpeBRepDS_Kind.TopOpeBRepDS_SOLID
TopOpeBRepDS_COMPSOLID = TopOpeBRepDS_Kind.TopOpeBRepDS_COMPSOLID
TopOpeBRepDS_COMPOUND = TopOpeBRepDS_Kind.TopOpeBRepDS_COMPOUND
TopOpeBRepDS_UNKNOWN = TopOpeBRepDS_Kind.TopOpeBRepDS_UNKNOWN

class topopebrepds:
	@staticmethod
	def IsGeometry(K: TopOpeBRepDS_Kind) -> bool: ...
	@staticmethod
	def IsTopology(K: TopOpeBRepDS_Kind) -> bool: ...
	@staticmethod
	def KindToShape(K: TopOpeBRepDS_Kind) -> TopAbs_ShapeEnum: ...
	@overload
	@staticmethod
	def SPrint(S: TopAbs_State) -> TCollection_AsciiString: ...
	@overload
	@staticmethod
	def SPrint(K: TopOpeBRepDS_Kind) -> TCollection_AsciiString: ...
	@overload
	@staticmethod
	def SPrint(K: TopOpeBRepDS_Kind, I: int, B: Optional[TCollection_AsciiString] = "", A: Optional[TCollection_AsciiString] = "") -> TCollection_AsciiString: ...
	@overload
	@staticmethod
	def SPrint(T: TopAbs_ShapeEnum) -> TCollection_AsciiString: ...
	@overload
	@staticmethod
	def SPrint(T: TopAbs_ShapeEnum, I: int) -> TCollection_AsciiString: ...
	@overload
	@staticmethod
	def SPrint(O: TopAbs_Orientation) -> TCollection_AsciiString: ...
	@overload
	@staticmethod
	def SPrint(C: TopOpeBRepDS_Config) -> TCollection_AsciiString: ...
	@staticmethod
	def ShapeToKind(S: TopAbs_ShapeEnum) -> TopOpeBRepDS_Kind: ...

class TopOpeBRepDS_Association(Standard_Transient):
	def __init__(self) -> None: ...
	def AreAssociated(self, I: TopOpeBRepDS_Interference, K: TopOpeBRepDS_Interference) -> bool: ...
	@overload
	def Associate(self, I: TopOpeBRepDS_Interference, K: TopOpeBRepDS_Interference) -> None: ...
	@overload
	def Associate(self, I: TopOpeBRepDS_Interference, LI: TopOpeBRepDS_ListOfInterference) -> None: ...
	def Associated(self, I: TopOpeBRepDS_Interference) -> TopOpeBRepDS_ListOfInterference: ...
	def HasAssociation(self, I: TopOpeBRepDS_Interference) -> bool: ...

class TopOpeBRepDS_BuildTool:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, OutCurveType: TopOpeBRepTool_OutCurveType) -> None: ...
	@overload
	def __init__(self, GT: TopOpeBRepTool_GeomTool) -> None: ...
	@overload
	def AddEdgeVertex(self, Ein: TopoDS_Shape, Eou: TopoDS_Shape, V: TopoDS_Shape) -> None: ...
	@overload
	def AddEdgeVertex(self, E: TopoDS_Shape, V: TopoDS_Shape) -> None: ...
	def AddFaceWire(self, F: TopoDS_Shape, W: TopoDS_Shape) -> None: ...
	def AddShellFace(self, Sh: TopoDS_Shape, F: TopoDS_Shape) -> None: ...
	def AddSolidShell(self, S: TopoDS_Shape, Sh: TopoDS_Shape) -> None: ...
	def AddWireEdge(self, W: TopoDS_Shape, E: TopoDS_Shape) -> None: ...
	def ApproxCurves(self, C: TopOpeBRepDS_Curve, E: TopoDS_Edge, HDS: TopOpeBRepDS_HDataStructure) -> int: ...
	def Approximation(self) -> bool: ...
	def ChangeGeomTool(self) -> TopOpeBRepTool_GeomTool: ...
	def Closed(self, S: TopoDS_Shape, B: bool) -> None: ...
	def ComputePCurves(self, C: TopOpeBRepDS_Curve, E: TopoDS_Edge, newC: TopOpeBRepDS_Curve, CompPC1: bool, CompPC2: bool, CompC3D: bool) -> None: ...
	def CopyEdge(self, Ein: TopoDS_Shape, Eou: TopoDS_Shape) -> None: ...
	def CopyFace(self, Fin: TopoDS_Shape, Fou: TopoDS_Shape) -> None: ...
	def Curve3D(self, E: TopoDS_Shape, C: Geom_Curve, Tol: float) -> None: ...
	def GetGeomTool(self) -> TopOpeBRepTool_GeomTool: ...
	def GetOrientedEdgeVertices(self, E: TopoDS_Edge, Vmin: TopoDS_Vertex, Vmax: TopoDS_Vertex) -> Tuple[float, float]: ...
	@overload
	def MakeEdge(self, E: TopoDS_Shape, C: TopOpeBRepDS_Curve) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Shape, C: TopOpeBRepDS_Curve, DS: TopOpeBRepDS_DataStructure) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Shape, C: Geom_Curve, Tol: float) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Shape) -> None: ...
	def MakeFace(self, F: TopoDS_Shape, S: TopOpeBRepDS_Surface) -> None: ...
	def MakeShell(self, Sh: TopoDS_Shape) -> None: ...
	def MakeSolid(self, S: TopoDS_Shape) -> None: ...
	def MakeVertex(self, V: TopoDS_Shape, P: TopOpeBRepDS_Point) -> None: ...
	def MakeWire(self, W: TopoDS_Shape) -> None: ...
	@overload
	def Orientation(self, S: TopoDS_Shape, O: TopAbs_Orientation) -> None: ...
	@overload
	def Orientation(self, S: TopoDS_Shape) -> TopAbs_Orientation: ...
	@overload
	def OverWrite(self) -> bool: ...
	@overload
	def OverWrite(self, O: bool) -> None: ...
	@overload
	def PCurve(self, F: TopoDS_Shape, E: TopoDS_Shape, C: Geom2d_Curve) -> None: ...
	@overload
	def PCurve(self, F: TopoDS_Shape, E: TopoDS_Shape, CDS: TopOpeBRepDS_Curve, C: Geom2d_Curve) -> None: ...
	@overload
	def Parameter(self, E: TopoDS_Shape, V: TopoDS_Shape, P: float) -> None: ...
	@overload
	def Parameter(self, C: TopOpeBRepDS_Curve, E: TopoDS_Shape, V: TopoDS_Shape) -> None: ...
	def PutPCurves(self, newC: TopOpeBRepDS_Curve, E: TopoDS_Edge, CompPC1: bool, CompPC2: bool) -> None: ...
	def Range(self, E: TopoDS_Shape, first: float, last: float) -> None: ...
	def RecomputeCurves(self, C: TopOpeBRepDS_Curve, oldE: TopoDS_Edge, E: TopoDS_Edge, HDS: TopOpeBRepDS_HDataStructure) -> int: ...
	@overload
	def Translate(self) -> bool: ...
	@overload
	def Translate(self, T: bool) -> None: ...
	def UpdateEdge(self, Ein: TopoDS_Shape, Eou: TopoDS_Shape) -> None: ...
	def UpdateEdgeCurveTol(self, F1: TopoDS_Face, F2: TopoDS_Face, E: TopoDS_Edge, C3Dnew: Geom_Curve, tol3d: float, tol2d1: float, tol2d2: float) -> Tuple[float, float, float]: ...
	@overload
	def UpdateSurface(self, F: TopoDS_Shape, SU: Geom_Surface) -> None: ...
	@overload
	def UpdateSurface(self, E: TopoDS_Shape, oldF: TopoDS_Shape, newF: TopoDS_Shape) -> None: ...

class TopOpeBRepDS_Check(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def ChangeHDS(self) -> TopOpeBRepDS_HDataStructure: ...
	def CheckDS(self, i: int, K: TopOpeBRepDS_Kind) -> bool: ...
	def CheckShapes(self, LS: TopTools_ListOfShape) -> bool: ...
	def ChkIntg(self) -> bool: ...
	def ChkIntgInterf(self, LI: TopOpeBRepDS_ListOfInterference) -> bool: ...
	def ChkIntgSamDom(self) -> bool: ...
	def HDS(self) -> TopOpeBRepDS_HDataStructure: ...
	def OneVertexOnPnt(self) -> bool: ...

class TopOpeBRepDS_Curve:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: Geom_Curve, T: float, IsWalk: Optional[bool] = False) -> None: ...
	def ChangeCurve(self) -> Geom_Curve: ...
	def ChangeDSIndex(self, I: int) -> None: ...
	def ChangeIsWalk(self, B: bool) -> None: ...
	def ChangeKeep(self, B: bool) -> None: ...
	def ChangeMother(self, I: int) -> None: ...
	def ChangeShape1(self) -> TopoDS_Shape: ...
	def ChangeShape2(self) -> TopoDS_Shape: ...
	@overload
	def Curve(self) -> Geom_Curve: ...
	@overload
	def Curve(self, C3D: Geom_Curve, Tol: float) -> None: ...
	@overload
	def Curve1(self) -> Geom2d_Curve: ...
	@overload
	def Curve1(self, PC1: Geom2d_Curve) -> None: ...
	@overload
	def Curve2(self) -> Geom2d_Curve: ...
	@overload
	def Curve2(self, PC2: Geom2d_Curve) -> None: ...
	def DSIndex(self) -> int: ...
	def DefineCurve(self, P: Geom_Curve, T: float, IsWalk: bool) -> None: ...
	def GetSCI(self, I1: TopOpeBRepDS_Interference, I2: TopOpeBRepDS_Interference) -> None: ...
	def GetSCI1(self) -> TopOpeBRepDS_Interference: ...
	def GetSCI2(self) -> TopOpeBRepDS_Interference: ...
	def GetShapes(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...
	def IsWalk(self) -> bool: ...
	def Keep(self) -> bool: ...
	def Mother(self) -> int: ...
	def Range(self) -> Tuple[bool, float, float]: ...
	def SetRange(self, First: float, Last: float) -> None: ...
	def SetSCI(self, I1: TopOpeBRepDS_Interference, I2: TopOpeBRepDS_Interference) -> None: ...
	def SetShapes(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...
	def Shape1(self) -> TopoDS_Shape: ...
	def Shape2(self) -> TopoDS_Shape: ...
	@overload
	def Tolerance(self, tol: float) -> None: ...
	@overload
	def Tolerance(self) -> float: ...

class TopOpeBRepDS_CurveExplorer:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, DS: TopOpeBRepDS_DataStructure, FindOnlyKeep: Optional[bool] = True) -> None: ...
	@overload
	def Curve(self) -> TopOpeBRepDS_Curve: ...
	@overload
	def Curve(self, I: int) -> TopOpeBRepDS_Curve: ...
	def Index(self) -> int: ...
	def Init(self, DS: TopOpeBRepDS_DataStructure, FindOnlyKeep: Optional[bool] = True) -> None: ...
	def IsCurve(self, I: int) -> bool: ...
	def IsCurveKeep(self, I: int) -> bool: ...
	def More(self) -> bool: ...
	def NbCurve(self) -> int: ...
	def Next(self) -> None: ...

class TopOpeBRepDS_DataStructure:
	def __init__(self) -> None: ...
	def AddCurve(self, S: TopOpeBRepDS_Curve) -> int: ...
	def AddPoint(self, PDS: TopOpeBRepDS_Point) -> int: ...
	def AddPointSS(self, PDS: TopOpeBRepDS_Point, S1: TopoDS_Shape, S2: TopoDS_Shape) -> int: ...
	def AddSectionEdge(self, E: TopoDS_Edge) -> int: ...
	@overload
	def AddShape(self, S: TopoDS_Shape) -> int: ...
	@overload
	def AddShape(self, S: TopoDS_Shape, I: int) -> int: ...
	def AddShapeInterference(self, S: TopoDS_Shape, I: TopOpeBRepDS_Interference) -> None: ...
	def AddShapeSameDomain(self, S: TopoDS_Shape, SSD: TopoDS_Shape) -> None: ...
	def AddSurface(self, S: TopOpeBRepDS_Surface) -> int: ...
	@overload
	def AncestorRank(self, I: int) -> int: ...
	@overload
	def AncestorRank(self, S: TopoDS_Shape) -> int: ...
	@overload
	def AncestorRank(self, I: int, Ianc: int) -> None: ...
	@overload
	def AncestorRank(self, S: TopoDS_Shape, Ianc: int) -> None: ...
	def ChangeCurve(self, I: int) -> TopOpeBRepDS_Curve: ...
	def ChangeCurveInterferences(self, I: int) -> TopOpeBRepDS_ListOfInterference: ...
	@overload
	def ChangeKeepCurve(self, I: int, FindKeep: bool) -> None: ...
	@overload
	def ChangeKeepCurve(self, C: TopOpeBRepDS_Curve, FindKeep: bool) -> None: ...
	@overload
	def ChangeKeepPoint(self, I: int, FindKeep: bool) -> None: ...
	@overload
	def ChangeKeepPoint(self, P: TopOpeBRepDS_Point, FindKeep: bool) -> None: ...
	@overload
	def ChangeKeepShape(self, I: int, FindKeep: bool) -> None: ...
	@overload
	def ChangeKeepShape(self, S: TopoDS_Shape, FindKeep: bool) -> None: ...
	@overload
	def ChangeKeepSurface(self, I: int, FindKeep: bool) -> None: ...
	@overload
	def ChangeKeepSurface(self, S: TopOpeBRepDS_Surface, FindKeep: bool) -> None: ...
	def ChangeMapOfRejectedShapesObj(self) -> TopTools_IndexedMapOfShape: ...
	def ChangeMapOfRejectedShapesTool(self) -> TopTools_IndexedMapOfShape: ...
	def ChangeMapOfShapeWithState(self, aShape: TopoDS_Shape) -> Tuple[TopOpeBRepDS_IndexedDataMapOfShapeWithState, bool]: ...
	def ChangeMapOfShapeWithStateObj(self) -> TopOpeBRepDS_IndexedDataMapOfShapeWithState: ...
	def ChangeMapOfShapeWithStateTool(self) -> TopOpeBRepDS_IndexedDataMapOfShapeWithState: ...
	def ChangeNbCurves(self, N: int) -> None: ...
	def ChangePoint(self, I: int) -> TopOpeBRepDS_Point: ...
	def ChangePointInterferences(self, I: int) -> TopOpeBRepDS_ListOfInterference: ...
	@overload
	def ChangeShapeInterferences(self, S: TopoDS_Shape) -> TopOpeBRepDS_ListOfInterference: ...
	@overload
	def ChangeShapeInterferences(self, I: int) -> TopOpeBRepDS_ListOfInterference: ...
	@overload
	def ChangeShapeSameDomain(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	@overload
	def ChangeShapeSameDomain(self, I: int) -> TopTools_ListOfShape: ...
	def ChangeShapes(self) -> TopOpeBRepDS_MapOfShapeData: ...
	def ChangeSurface(self, I: int) -> TopOpeBRepDS_Surface: ...
	def ChangeSurfaceInterferences(self, I: int) -> TopOpeBRepDS_ListOfInterference: ...
	def Curve(self, I: int) -> TopOpeBRepDS_Curve: ...
	def CurveInterferences(self, I: int) -> TopOpeBRepDS_ListOfInterference: ...
	@overload
	def FillShapesSameDomain(self, S1: TopoDS_Shape, S2: TopoDS_Shape, refFirst: Optional[bool] = True) -> None: ...
	@overload
	def FillShapesSameDomain(self, S1: TopoDS_Shape, S2: TopoDS_Shape, c1: TopOpeBRepDS_Config, c2: TopOpeBRepDS_Config, refFirst: Optional[bool] = True) -> None: ...
	def GetShapeWithState(self, aShape: TopoDS_Shape) -> TopOpeBRepDS_ShapeWithState: ...
	def HasGeometry(self, S: TopoDS_Shape) -> bool: ...
	def HasNewSurface(self, F: TopoDS_Shape) -> bool: ...
	def HasShape(self, S: TopoDS_Shape, FindKeep: Optional[bool] = True) -> bool: ...
	def Init(self) -> None: ...
	def InitSectionEdges(self) -> None: ...
	def IsSectionEdge(self, E: TopoDS_Edge, FindKeep: Optional[bool] = True) -> bool: ...
	@overload
	def Isfafa(self, isfafa: bool) -> None: ...
	@overload
	def Isfafa(self) -> bool: ...
	@overload
	def KeepCurve(self, I: int) -> bool: ...
	@overload
	def KeepCurve(self, C: TopOpeBRepDS_Curve) -> bool: ...
	@overload
	def KeepPoint(self, I: int) -> bool: ...
	@overload
	def KeepPoint(self, P: TopOpeBRepDS_Point) -> bool: ...
	@overload
	def KeepShape(self, I: int, FindKeep: Optional[bool] = True) -> bool: ...
	@overload
	def KeepShape(self, S: TopoDS_Shape, FindKeep: Optional[bool] = True) -> bool: ...
	@overload
	def KeepSurface(self, I: int) -> bool: ...
	@overload
	def KeepSurface(self, S: TopOpeBRepDS_Surface) -> bool: ...
	def NbCurves(self) -> int: ...
	def NbPoints(self) -> int: ...
	def NbSectionEdges(self) -> int: ...
	def NbShapes(self) -> int: ...
	def NbSurfaces(self) -> int: ...
	def NewSurface(self, F: TopoDS_Shape) -> Geom_Surface: ...
	def Point(self, I: int) -> TopOpeBRepDS_Point: ...
	def PointInterferences(self, I: int) -> TopOpeBRepDS_ListOfInterference: ...
	def RemoveCurve(self, I: int) -> None: ...
	def RemovePoint(self, I: int) -> None: ...
	def RemoveShapeInterference(self, S: TopoDS_Shape, I: TopOpeBRepDS_Interference) -> None: ...
	def RemoveShapeSameDomain(self, S: TopoDS_Shape, SSD: TopoDS_Shape) -> None: ...
	def RemoveSurface(self, I: int) -> None: ...
	@overload
	def SameDomainInd(self, I: int) -> int: ...
	@overload
	def SameDomainInd(self, S: TopoDS_Shape) -> int: ...
	@overload
	def SameDomainInd(self, I: int, Ind: int) -> None: ...
	@overload
	def SameDomainInd(self, S: TopoDS_Shape, Ind: int) -> None: ...
	@overload
	def SameDomainOri(self, I: int) -> TopOpeBRepDS_Config: ...
	@overload
	def SameDomainOri(self, S: TopoDS_Shape) -> TopOpeBRepDS_Config: ...
	@overload
	def SameDomainOri(self, I: int, Ori: TopOpeBRepDS_Config) -> None: ...
	@overload
	def SameDomainOri(self, S: TopoDS_Shape, Ori: TopOpeBRepDS_Config) -> None: ...
	@overload
	def SameDomainRef(self, I: int) -> int: ...
	@overload
	def SameDomainRef(self, S: TopoDS_Shape) -> int: ...
	@overload
	def SameDomainRef(self, I: int, Ref: int) -> None: ...
	@overload
	def SameDomainRef(self, S: TopoDS_Shape, Ref: int) -> None: ...
	@overload
	def SectionEdge(self, I: int, FindKeep: Optional[bool] = True) -> TopoDS_Edge: ...
	@overload
	def SectionEdge(self, E: TopoDS_Edge, FindKeep: Optional[bool] = True) -> int: ...
	def SetNewSurface(self, F: TopoDS_Shape, S: Geom_Surface) -> None: ...
	@overload
	def Shape(self, I: int, FindKeep: Optional[bool] = True) -> TopoDS_Shape: ...
	@overload
	def Shape(self, S: TopoDS_Shape, FindKeep: Optional[bool] = True) -> int: ...
	@overload
	def ShapeInterferences(self, S: TopoDS_Shape, FindKeep: Optional[bool] = True) -> TopOpeBRepDS_ListOfInterference: ...
	@overload
	def ShapeInterferences(self, I: int, FindKeep: Optional[bool] = True) -> TopOpeBRepDS_ListOfInterference: ...
	@overload
	def ShapeSameDomain(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	@overload
	def ShapeSameDomain(self, I: int) -> TopTools_ListOfShape: ...
	def Surface(self, I: int) -> TopOpeBRepDS_Surface: ...
	def SurfaceInterferences(self, I: int) -> TopOpeBRepDS_ListOfInterference: ...
	def UnfillShapesSameDomain(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...

class TopOpeBRepDS_Dumper:
	def __init__(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	@overload
	def SDumpRefOri(self, K: TopOpeBRepDS_Kind, I: int) -> TCollection_AsciiString: ...
	@overload
	def SDumpRefOri(self, S: TopoDS_Shape) -> TCollection_AsciiString: ...
	@overload
	def SPrintShape(self, I: int) -> TCollection_AsciiString: ...
	@overload
	def SPrintShape(self, S: TopoDS_Shape) -> TCollection_AsciiString: ...
	@overload
	def SPrintShapeRefOri(self, S: TopoDS_Shape, B: Optional[TCollection_AsciiString] = "") -> TCollection_AsciiString: ...
	@overload
	def SPrintShapeRefOri(self, L: TopTools_ListOfShape, B: Optional[TCollection_AsciiString] = "") -> TCollection_AsciiString: ...

class TopOpeBRepDS_EIR:
	def __init__(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	@overload
	def ProcessEdgeInterferences(self) -> None: ...
	@overload
	def ProcessEdgeInterferences(self, I: int) -> None: ...

class TopOpeBRepDS_Edge3dInterferenceTool:
	def __init__(self) -> None: ...
	def Add(self, Eref: TopoDS_Shape, E: TopoDS_Shape, F: TopoDS_Shape, I: TopOpeBRepDS_Interference) -> None: ...
	def Init(self, Eref: TopoDS_Shape, E: TopoDS_Shape, F: TopoDS_Shape, I: TopOpeBRepDS_Interference) -> None: ...
	def InitPointVertex(self, IsVertex: int, VonOO: TopoDS_Shape) -> None: ...
	def Transition(self, I: TopOpeBRepDS_Interference) -> None: ...

class TopOpeBRepDS_EdgeInterferenceTool:
	def __init__(self) -> None: ...
	@overload
	def Add(self, E: TopoDS_Shape, V: TopoDS_Shape, I: TopOpeBRepDS_Interference) -> None: ...
	@overload
	def Add(self, E: TopoDS_Shape, P: TopOpeBRepDS_Point, I: TopOpeBRepDS_Interference) -> None: ...
	def Init(self, E: TopoDS_Shape, I: TopOpeBRepDS_Interference) -> None: ...
	def Transition(self, I: TopOpeBRepDS_Interference) -> None: ...

class TopOpeBRepDS_Explorer:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, HDS: TopOpeBRepDS_HDataStructure, T: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE, findkeep: Optional[bool] = True) -> None: ...
	def Current(self) -> TopoDS_Shape: ...
	def Edge(self) -> TopoDS_Edge: ...
	def Face(self) -> TopoDS_Face: ...
	def Index(self) -> int: ...
	def Init(self, HDS: TopOpeBRepDS_HDataStructure, T: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE, findkeep: Optional[bool] = True) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Type(self) -> TopAbs_ShapeEnum: ...
	def Vertex(self) -> TopoDS_Vertex: ...

class TopOpeBRepDS_FIR:
	def __init__(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	@overload
	def ProcessFaceInterferences(self, M: TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State) -> None: ...
	@overload
	def ProcessFaceInterferences(self, I: int, M: TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State) -> None: ...

class TopOpeBRepDS_FaceInterferenceTool:
	def __init__(self, P: TopOpeBRepDS_PDataStructure) -> None: ...
	@overload
	def Add(self, FI: TopoDS_Shape, F: TopoDS_Shape, E: TopoDS_Shape, Eisnew: bool, I: TopOpeBRepDS_Interference) -> None: ...
	@overload
	def Add(self, E: TopoDS_Shape, C: TopOpeBRepDS_Curve, I: TopOpeBRepDS_Interference) -> None: ...
	def GetEdgePntPar(self, P: gp_Pnt) -> float: ...
	def Init(self, FI: TopoDS_Shape, E: TopoDS_Shape, Eisnew: bool, I: TopOpeBRepDS_Interference) -> None: ...
	def IsEdgePntParDef(self) -> bool: ...
	def SetEdgePntPar(self, P: gp_Pnt, par: float) -> None: ...
	def Transition(self, I: TopOpeBRepDS_Interference) -> None: ...

class TopOpeBRepDS_Filter:
	def __init__(self, HDS: TopOpeBRepDS_HDataStructure, pClassif: Optional[TopOpeBRepTool_PShapeClassifier] = 0) -> None: ...
	@overload
	def ProcessCurveInterferences(self) -> None: ...
	@overload
	def ProcessCurveInterferences(self, I: int) -> None: ...
	@overload
	def ProcessEdgeInterferences(self) -> None: ...
	@overload
	def ProcessEdgeInterferences(self, I: int) -> None: ...
	@overload
	def ProcessFaceInterferences(self, MEsp: TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State) -> None: ...
	@overload
	def ProcessFaceInterferences(self, I: int, MEsp: TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State) -> None: ...
	def ProcessInterferences(self) -> None: ...

class TopOpeBRepDS_GapFiller:
	def __init__(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def AddPointsOnConnexShape(self, F: TopoDS_Shape, LI: TopOpeBRepDS_ListOfInterference) -> None: ...
	def AddPointsOnShape(self, S: TopoDS_Shape, LI: TopOpeBRepDS_ListOfInterference) -> None: ...
	def BuildNewGeometries(self) -> None: ...
	def CheckConnexity(self, LI: TopOpeBRepDS_ListOfInterference) -> bool: ...
	def FilterByEdge(self, E: TopoDS_Edge, LI: TopOpeBRepDS_ListOfInterference) -> None: ...
	def FilterByFace(self, F: TopoDS_Face, LI: TopOpeBRepDS_ListOfInterference) -> None: ...
	def FilterByIncidentDistance(self, F: TopoDS_Face, I: TopOpeBRepDS_Interference, LI: TopOpeBRepDS_ListOfInterference) -> None: ...
	def FindAssociatedPoints(self, I: TopOpeBRepDS_Interference, LI: TopOpeBRepDS_ListOfInterference) -> None: ...
	def IsOnEdge(self, I: TopOpeBRepDS_Interference, E: TopoDS_Edge) -> bool: ...
	def IsOnFace(self, I: TopOpeBRepDS_Interference, F: TopoDS_Face) -> bool: ...
	def Perform(self) -> None: ...
	def ReBuildGeom(self, I1: TopOpeBRepDS_Interference, Done: TColStd_MapOfInteger) -> None: ...

class TopOpeBRepDS_GapTool(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def ChangeSameInterferences(self, I: TopOpeBRepDS_Interference) -> TopOpeBRepDS_ListOfInterference: ...
	def Curve(self, I: TopOpeBRepDS_Interference, C: TopOpeBRepDS_Curve) -> bool: ...
	def EdgeSupport(self, I: TopOpeBRepDS_Interference, E: TopoDS_Shape) -> bool: ...
	def FacesSupport(self, I: TopOpeBRepDS_Interference, F1: TopoDS_Shape, F2: TopoDS_Shape) -> bool: ...
	def Init(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def Interferences(self, IndexPoint: int) -> TopOpeBRepDS_ListOfInterference: ...
	def ParameterOnEdge(self, I: TopOpeBRepDS_Interference, E: TopoDS_Shape) -> Tuple[bool, float]: ...
	def SameInterferences(self, I: TopOpeBRepDS_Interference) -> TopOpeBRepDS_ListOfInterference: ...
	def SetParameterOnEdge(self, I: TopOpeBRepDS_Interference, E: TopoDS_Shape, U: float) -> None: ...
	def SetPoint(self, I: TopOpeBRepDS_Interference, IndexPoint: int) -> None: ...

class TopOpeBRepDS_GeometryData:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Other: TopOpeBRepDS_GeometryData) -> None: ...
	def AddInterference(self, I: TopOpeBRepDS_Interference) -> None: ...
	def Assign(self, Other: TopOpeBRepDS_GeometryData) -> None: ...
	def ChangeInterferences(self) -> TopOpeBRepDS_ListOfInterference: ...
	def Interferences(self) -> TopOpeBRepDS_ListOfInterference: ...

class TopOpeBRepDS_Interference(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Transition: TopOpeBRepDS_Transition, SupportType: TopOpeBRepDS_Kind, Support: int, GeometryType: TopOpeBRepDS_Kind, Geometry: int) -> None: ...
	@overload
	def __init__(self, I: TopOpeBRepDS_Interference) -> None: ...
	def ChangeTransition(self) -> TopOpeBRepDS_Transition: ...
	def GKGSKS(self, GK: TopOpeBRepDS_Kind, SK: TopOpeBRepDS_Kind) -> Tuple[int, int]: ...
	@overload
	def Geometry(self) -> int: ...
	@overload
	def Geometry(self, G: int) -> None: ...
	@overload
	def GeometryType(self) -> TopOpeBRepDS_Kind: ...
	@overload
	def GeometryType(self, GT: TopOpeBRepDS_Kind) -> None: ...
	def HasSameGeometry(self, Other: TopOpeBRepDS_Interference) -> bool: ...
	def HasSameSupport(self, Other: TopOpeBRepDS_Interference) -> bool: ...
	def SetGeometry(self, GI: int) -> None: ...
	@overload
	def Support(self) -> int: ...
	@overload
	def Support(self, S: int) -> None: ...
	@overload
	def SupportType(self) -> TopOpeBRepDS_Kind: ...
	@overload
	def SupportType(self, ST: TopOpeBRepDS_Kind) -> None: ...
	@overload
	def Transition(self) -> TopOpeBRepDS_Transition: ...
	@overload
	def Transition(self, T: TopOpeBRepDS_Transition) -> None: ...

class TopOpeBRepDS_InterferenceIterator:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, L: TopOpeBRepDS_ListOfInterference) -> None: ...
	def ChangeIterator(self) -> TopOpeBRepDS_ListIteratorOfListOfInterference: ...
	def Geometry(self, G: int) -> None: ...
	def GeometryKind(self, GK: TopOpeBRepDS_Kind) -> None: ...
	def Init(self, L: TopOpeBRepDS_ListOfInterference) -> None: ...
	def Match(self) -> None: ...
	def MatchInterference(self, I: TopOpeBRepDS_Interference) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Support(self, S: int) -> None: ...
	def SupportKind(self, ST: TopOpeBRepDS_Kind) -> None: ...
	def Value(self) -> TopOpeBRepDS_Interference: ...

class TopOpeBRepDS_InterferenceTool:
	@staticmethod
	def DuplicateCurvePointInterference(I: TopOpeBRepDS_Interference) -> TopOpeBRepDS_Interference: ...
	@staticmethod
	def MakeCurveInterference(T: TopOpeBRepDS_Transition, SK: TopOpeBRepDS_Kind, SI: int, GK: TopOpeBRepDS_Kind, GI: int, P: float) -> TopOpeBRepDS_Interference: ...
	@staticmethod
	def MakeEdgeInterference(T: TopOpeBRepDS_Transition, SK: TopOpeBRepDS_Kind, SI: int, GK: TopOpeBRepDS_Kind, GI: int, P: float) -> TopOpeBRepDS_Interference: ...
	@staticmethod
	def MakeEdgeVertexInterference(Transition: TopOpeBRepDS_Transition, EdgeI: int, VertexI: int, VertexIsBound: bool, Config: TopOpeBRepDS_Config, param: float) -> TopOpeBRepDS_Interference: ...
	@staticmethod
	def MakeFaceCurveInterference(Transition: TopOpeBRepDS_Transition, FaceI: int, CurveI: int, PC: Geom2d_Curve) -> TopOpeBRepDS_Interference: ...
	@staticmethod
	def MakeFaceEdgeInterference(Transition: TopOpeBRepDS_Transition, FaceI: int, EdgeI: int, EdgeIsBound: bool, Config: TopOpeBRepDS_Config) -> TopOpeBRepDS_Interference: ...
	@staticmethod
	def MakeSolidSurfaceInterference(Transition: TopOpeBRepDS_Transition, SolidI: int, SurfaceI: int) -> TopOpeBRepDS_Interference: ...
	@overload
	@staticmethod
	def Parameter(CPI: TopOpeBRepDS_Interference) -> float: ...
	@overload
	@staticmethod
	def Parameter(CPI: TopOpeBRepDS_Interference, Par: float) -> None: ...

class TopOpeBRepDS_ListOfShapeOn1State:
	def __init__(self) -> None: ...
	def ChangeListOnState(self) -> TopTools_ListOfShape: ...
	def Clear(self) -> None: ...
	def IsSplit(self) -> bool: ...
	def ListOnState(self) -> TopTools_ListOfShape: ...
	def Split(self, B: Optional[bool] = True) -> None: ...

class TopOpeBRepDS_Marker(Standard_Transient):
	def __init__(self) -> None: ...
	def Allocate(self, n: int) -> None: ...
	def GetI(self, i: int) -> bool: ...
	def Reset(self) -> None: ...
	@overload
	def Set(self, i: int, b: bool) -> None: ...
	@overload
	def Set(self, b: bool, n: int, a: None) -> None: ...

class TopOpeBRepDS_Point:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, T: float) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape) -> None: ...
	def ChangeKeep(self, B: bool) -> None: ...
	def ChangePoint(self) -> gp_Pnt: ...
	def IsEqual(self, other: TopOpeBRepDS_Point) -> bool: ...
	def Keep(self) -> bool: ...
	def Point(self) -> gp_Pnt: ...
	@overload
	def Tolerance(self) -> float: ...
	@overload
	def Tolerance(self, Tol: float) -> None: ...

class TopOpeBRepDS_PointExplorer:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, DS: TopOpeBRepDS_DataStructure, FindOnlyKeep: Optional[bool] = True) -> None: ...
	def Index(self) -> int: ...
	def Init(self, DS: TopOpeBRepDS_DataStructure, FindOnlyKeep: Optional[bool] = True) -> None: ...
	def IsPoint(self, I: int) -> bool: ...
	def IsPointKeep(self, I: int) -> bool: ...
	def More(self) -> bool: ...
	def NbPoint(self) -> int: ...
	def Next(self) -> None: ...
	@overload
	def Point(self) -> TopOpeBRepDS_Point: ...
	@overload
	def Point(self, I: int) -> TopOpeBRepDS_Point: ...

class TopOpeBRepDS_Reducer:
	def __init__(self, HDS: TopOpeBRepDS_HDataStructure) -> None: ...
	def ProcessEdgeInterferences(self) -> None: ...
	def ProcessFaceInterferences(self, M: TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State) -> None: ...

class TopOpeBRepDS_ShapeData:
	def __init__(self) -> None: ...
	def ChangeInterferences(self) -> TopOpeBRepDS_ListOfInterference: ...
	def ChangeKeep(self, B: bool) -> None: ...
	def Interferences(self) -> TopOpeBRepDS_ListOfInterference: ...
	def Keep(self) -> bool: ...

class TopOpeBRepDS_ShapeWithState:
	def __init__(self) -> None: ...
	def AddPart(self, aShape: TopoDS_Shape, aState: TopAbs_State) -> None: ...
	def AddParts(self, aListOfShape: TopTools_ListOfShape, aState: TopAbs_State) -> None: ...
	def IsSplitted(self) -> bool: ...
	def Part(self, aState: TopAbs_State) -> TopTools_ListOfShape: ...
	def SetIsSplitted(self, anIsSplitted: bool) -> None: ...
	def SetState(self, aState: TopAbs_State) -> None: ...
	def State(self) -> TopAbs_State: ...

class TopOpeBRepDS_Surface:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: Geom_Surface, T: float) -> None: ...
	@overload
	def __init__(self, Other: TopOpeBRepDS_Surface) -> None: ...
	def Assign(self, Other: TopOpeBRepDS_Surface) -> None: ...
	def ChangeKeep(self, theToKeep: bool) -> None: ...
	def Keep(self) -> bool: ...
	def Surface(self) -> Geom_Surface: ...
	@overload
	def Tolerance(self) -> float: ...
	@overload
	def Tolerance(self, theTol: float) -> None: ...

class TopOpeBRepDS_SurfaceExplorer:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, DS: TopOpeBRepDS_DataStructure, FindOnlyKeep: Optional[bool] = True) -> None: ...
	def Index(self) -> int: ...
	def Init(self, DS: TopOpeBRepDS_DataStructure, FindOnlyKeep: Optional[bool] = True) -> None: ...
	def IsSurface(self, I: int) -> bool: ...
	def IsSurfaceKeep(self, I: int) -> bool: ...
	def More(self) -> bool: ...
	def NbSurface(self) -> int: ...
	def Next(self) -> None: ...
	@overload
	def Surface(self) -> TopOpeBRepDS_Surface: ...
	@overload
	def Surface(self, I: int) -> TopOpeBRepDS_Surface: ...

class TopOpeBRepDS_TKI:
	def __init__(self) -> None: ...
	@overload
	def Add(self, K: TopOpeBRepDS_Kind, G: int) -> None: ...
	@overload
	def Add(self, K: TopOpeBRepDS_Kind, G: int, HI: TopOpeBRepDS_Interference) -> None: ...
	def ChangeInterferences(self, K: TopOpeBRepDS_Kind, G: int) -> TopOpeBRepDS_ListOfInterference: ...
	def ChangeValue(self, K: TopOpeBRepDS_Kind) -> Tuple[TopOpeBRepDS_ListOfInterference, int]: ...
	def Clear(self) -> None: ...
	def DumpTKIIterator(self, s1: Optional[TCollection_AsciiString] = "", s2: Optional[TCollection_AsciiString] = "") -> None: ...
	def FillOnGeometry(self, L: TopOpeBRepDS_ListOfInterference) -> None: ...
	def FillOnSupport(self, L: TopOpeBRepDS_ListOfInterference) -> None: ...
	def HasInterferences(self, K: TopOpeBRepDS_Kind, G: int) -> bool: ...
	def Init(self) -> None: ...
	def Interferences(self, K: TopOpeBRepDS_Kind, G: int) -> TopOpeBRepDS_ListOfInterference: ...
	def IsBound(self, K: TopOpeBRepDS_Kind, G: int) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Value(self, K: TopOpeBRepDS_Kind) -> Tuple[TopOpeBRepDS_ListOfInterference, int]: ...

class TopOpeBRepDS_TOOL:
	@staticmethod
	def EShareG(HDS: TopOpeBRepDS_HDataStructure, E: TopoDS_Edge, lEsd: TopTools_ListOfShape) -> int: ...
	@staticmethod
	def GetConfig(HDS: TopOpeBRepDS_HDataStructure, MEspON: TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State, ie: int, iesd: int) -> Tuple[bool, int]: ...
	@staticmethod
	def GetEsd(HDS: TopOpeBRepDS_HDataStructure, S: TopoDS_Shape, ie: int) -> Tuple[bool, int]: ...
	@staticmethod
	def ShareG(HDS: TopOpeBRepDS_HDataStructure, is1: int, is2: int) -> bool: ...
	@staticmethod
	def ShareSplitON(HDS: TopOpeBRepDS_HDataStructure, MspON: TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State, i1: int, i2: int, spON: TopoDS_Shape) -> bool: ...

class TopOpeBRepDS_Transition:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, StateBefore: TopAbs_State, StateAfter: TopAbs_State, ShapeBefore: Optional[TopAbs_ShapeEnum] = TopAbs_FACE, ShapeAfter: Optional[TopAbs_ShapeEnum] = TopAbs_FACE) -> None: ...
	@overload
	def __init__(self, O: TopAbs_Orientation) -> None: ...
	@overload
	def After(self, S: TopAbs_State, ShapeAfter: Optional[TopAbs_ShapeEnum] = TopAbs_FACE) -> None: ...
	@overload
	def After(self) -> TopAbs_State: ...
	@overload
	def Before(self, S: TopAbs_State, ShapeBefore: Optional[TopAbs_ShapeEnum] = TopAbs_FACE) -> None: ...
	@overload
	def Before(self) -> TopAbs_State: ...
	def Complement(self) -> TopOpeBRepDS_Transition: ...
	@overload
	def Index(self, I: int) -> None: ...
	@overload
	def Index(self) -> int: ...
	@overload
	def IndexAfter(self, I: int) -> None: ...
	@overload
	def IndexAfter(self) -> int: ...
	@overload
	def IndexBefore(self, I: int) -> None: ...
	@overload
	def IndexBefore(self) -> int: ...
	def IsUnknown(self) -> bool: ...
	def ONAfter(self) -> TopAbs_ShapeEnum: ...
	def ONBefore(self) -> TopAbs_ShapeEnum: ...
	def Orientation(self, S: TopAbs_State, T: Optional[TopAbs_ShapeEnum] = TopAbs_FACE) -> TopAbs_Orientation: ...
	@overload
	def Set(self, StateBefore: TopAbs_State, StateAfter: TopAbs_State, ShapeBefore: Optional[TopAbs_ShapeEnum] = TopAbs_FACE, ShapeAfter: Optional[TopAbs_ShapeEnum] = TopAbs_FACE) -> None: ...
	@overload
	def Set(self, O: TopAbs_Orientation) -> None: ...
	@overload
	def ShapeAfter(self, SE: TopAbs_ShapeEnum) -> None: ...
	@overload
	def ShapeAfter(self) -> TopAbs_ShapeEnum: ...
	@overload
	def ShapeBefore(self, SE: TopAbs_ShapeEnum) -> None: ...
	@overload
	def ShapeBefore(self) -> TopAbs_ShapeEnum: ...
	def StateAfter(self, S: TopAbs_State) -> None: ...
	def StateBefore(self, S: TopAbs_State) -> None: ...

class TopOpeBRepDS_CurveData(TopOpeBRepDS_GeometryData):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: TopOpeBRepDS_Curve) -> None: ...

class TopOpeBRepDS_CurveIterator(TopOpeBRepDS_InterferenceIterator):
	def __init__(self, L: TopOpeBRepDS_ListOfInterference) -> None: ...
	def Current(self) -> int: ...
	def MatchInterference(self, I: TopOpeBRepDS_Interference) -> bool: ...
	def Orientation(self, S: TopAbs_State) -> TopAbs_Orientation: ...
	def PCurve(self) -> Geom2d_Curve: ...

class TopOpeBRepDS_CurvePointInterference(TopOpeBRepDS_Interference):
	def __init__(self, T: TopOpeBRepDS_Transition, ST: TopOpeBRepDS_Kind, S: int, GT: TopOpeBRepDS_Kind, G: int, P: float) -> None: ...
	@overload
	def Parameter(self) -> float: ...
	@overload
	def Parameter(self, P: float) -> None: ...

class TopOpeBRepDS_PointData(TopOpeBRepDS_GeometryData):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: TopOpeBRepDS_Point) -> None: ...
	@overload
	def __init__(self, P: TopOpeBRepDS_Point, I1: int, I2: int) -> None: ...
	def GetShapes(self) -> Tuple[int, int]: ...
	def SetShapes(self, I1: int, I2: int) -> None: ...

class TopOpeBRepDS_PointIterator(TopOpeBRepDS_InterferenceIterator):
	def __init__(self, L: TopOpeBRepDS_ListOfInterference) -> None: ...
	def Current(self) -> int: ...
	def DiffOriented(self) -> bool: ...
	def IsPoint(self) -> bool: ...
	def IsVertex(self) -> bool: ...
	def MatchInterference(self, I: TopOpeBRepDS_Interference) -> bool: ...
	def Orientation(self, S: TopAbs_State) -> TopAbs_Orientation: ...
	def Parameter(self) -> float: ...
	def SameOriented(self) -> bool: ...
	def Support(self) -> int: ...

class TopOpeBRepDS_ShapeShapeInterference(TopOpeBRepDS_Interference):
	def __init__(self, T: TopOpeBRepDS_Transition, ST: TopOpeBRepDS_Kind, S: int, GT: TopOpeBRepDS_Kind, G: int, GBound: bool, C: TopOpeBRepDS_Config) -> None: ...
	def Config(self) -> TopOpeBRepDS_Config: ...
	def GBound(self) -> bool: ...
	def SetGBound(self, b: bool) -> None: ...

class TopOpeBRepDS_SolidSurfaceInterference(TopOpeBRepDS_Interference):
	def __init__(self, Transition: TopOpeBRepDS_Transition, SupportType: TopOpeBRepDS_Kind, Support: int, GeometryType: TopOpeBRepDS_Kind, Geometry: int) -> None: ...

class TopOpeBRepDS_SurfaceCurveInterference(TopOpeBRepDS_Interference):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Transition: TopOpeBRepDS_Transition, SupportType: TopOpeBRepDS_Kind, Support: int, GeometryType: TopOpeBRepDS_Kind, Geometry: int, PC: Geom2d_Curve) -> None: ...
	@overload
	def __init__(self, I: TopOpeBRepDS_Interference) -> None: ...
	@overload
	def PCurve(self) -> Geom2d_Curve: ...
	@overload
	def PCurve(self, PC: Geom2d_Curve) -> None: ...

class TopOpeBRepDS_SurfaceData(TopOpeBRepDS_GeometryData):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopOpeBRepDS_Surface) -> None: ...

class TopOpeBRepDS_SurfaceIterator(TopOpeBRepDS_InterferenceIterator):
	def __init__(self, L: TopOpeBRepDS_ListOfInterference) -> None: ...
	def Current(self) -> int: ...
	def Orientation(self, S: TopAbs_State) -> TopAbs_Orientation: ...

class TopOpeBRepDS_EdgeVertexInterference(TopOpeBRepDS_ShapeShapeInterference):
	@overload
	def __init__(self, T: TopOpeBRepDS_Transition, ST: TopOpeBRepDS_Kind, S: int, G: int, GIsBound: bool, C: TopOpeBRepDS_Config, P: float) -> None: ...
	@overload
	def __init__(self, T: TopOpeBRepDS_Transition, S: int, G: int, GIsBound: bool, C: TopOpeBRepDS_Config, P: float) -> None: ...
	@overload
	def Parameter(self) -> float: ...
	@overload
	def Parameter(self, P: float) -> None: ...

class TopOpeBRepDS_FaceEdgeInterference(TopOpeBRepDS_ShapeShapeInterference):
	def __init__(self, T: TopOpeBRepDS_Transition, S: int, G: int, GIsBound: bool, C: TopOpeBRepDS_Config) -> None: ...

#classnotwrapped
class TopOpeBRepDS_DSS: ...

#classnotwrapped
class TopOpeBRepDS_HDataStructure: ...

# harray1 classes

class TopOpeBRepDS_HArray1OfDataMapOfIntegerListOfInterference(TopOpeBRepDS_Array1OfDataMapOfIntegerListOfInterference, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TopOpeBRepDS_Array1OfDataMapOfIntegerListOfInterference: ...

# harray2 classes
# hsequence classes

topopebrepds_IsGeometry = topopebrepds.IsGeometry
topopebrepds_IsTopology = topopebrepds.IsTopology
topopebrepds_KindToShape = topopebrepds.KindToShape
topopebrepds_Print = topopebrepds.Print
topopebrepds_Print = topopebrepds.Print
topopebrepds_Print = topopebrepds.Print
topopebrepds_Print = topopebrepds.Print
topopebrepds_Print = topopebrepds.Print
topopebrepds_SPrint = topopebrepds.SPrint
topopebrepds_SPrint = topopebrepds.SPrint
topopebrepds_SPrint = topopebrepds.SPrint
topopebrepds_SPrint = topopebrepds.SPrint
topopebrepds_SPrint = topopebrepds.SPrint
topopebrepds_SPrint = topopebrepds.SPrint
topopebrepds_SPrint = topopebrepds.SPrint
topopebrepds_ShapeToKind = topopebrepds.ShapeToKind
TopOpeBRepDS_InterferenceTool_DuplicateCurvePointInterference = TopOpeBRepDS_InterferenceTool.DuplicateCurvePointInterference
TopOpeBRepDS_InterferenceTool_MakeCurveInterference = TopOpeBRepDS_InterferenceTool.MakeCurveInterference
TopOpeBRepDS_InterferenceTool_MakeEdgeInterference = TopOpeBRepDS_InterferenceTool.MakeEdgeInterference
TopOpeBRepDS_InterferenceTool_MakeEdgeVertexInterference = TopOpeBRepDS_InterferenceTool.MakeEdgeVertexInterference
TopOpeBRepDS_InterferenceTool_MakeFaceCurveInterference = TopOpeBRepDS_InterferenceTool.MakeFaceCurveInterference
TopOpeBRepDS_InterferenceTool_MakeFaceEdgeInterference = TopOpeBRepDS_InterferenceTool.MakeFaceEdgeInterference
TopOpeBRepDS_InterferenceTool_MakeSolidSurfaceInterference = TopOpeBRepDS_InterferenceTool.MakeSolidSurfaceInterference
TopOpeBRepDS_InterferenceTool_Parameter = TopOpeBRepDS_InterferenceTool.Parameter
TopOpeBRepDS_InterferenceTool_Parameter = TopOpeBRepDS_InterferenceTool.Parameter
TopOpeBRepDS_TOOL_EShareG = TopOpeBRepDS_TOOL.EShareG
TopOpeBRepDS_TOOL_GetConfig = TopOpeBRepDS_TOOL.GetConfig
TopOpeBRepDS_TOOL_GetEsd = TopOpeBRepDS_TOOL.GetEsd
TopOpeBRepDS_TOOL_ShareG = TopOpeBRepDS_TOOL.ShareG
TopOpeBRepDS_TOOL_ShareSplitON = TopOpeBRepDS_TOOL.ShareSplitON



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Bisector module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_bisector.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Bisector
else:
    import _Bisector

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Bisector.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Bisector.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Bisector.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Bisector.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Bisector.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Bisector.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Bisector.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Bisector.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Bisector.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Bisector.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Bisector.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Bisector.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Bisector.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Bisector.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Bisector.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Bisector.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Bisector.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Bisector:
_Bisector.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Bisector.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom2d
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.IntRes2d

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_Bisector_Curve_Create() -> "opencascade::handle< Bisector_Curve >":
    return _Bisector.Handle_Bisector_Curve_Create()

def Handle_Bisector_Curve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Bisector_Curve >":
    return _Bisector.Handle_Bisector_Curve_DownCast(t)

def Handle_Bisector_Curve_IsNull(t: "opencascade::handle< Bisector_Curve > const &") -> "bool":
    return _Bisector.Handle_Bisector_Curve_IsNull(t)

def Handle_Bisector_BisecAna_Create() -> "opencascade::handle< Bisector_BisecAna >":
    return _Bisector.Handle_Bisector_BisecAna_Create()

def Handle_Bisector_BisecAna_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Bisector_BisecAna >":
    return _Bisector.Handle_Bisector_BisecAna_DownCast(t)

def Handle_Bisector_BisecAna_IsNull(t: "opencascade::handle< Bisector_BisecAna > const &") -> "bool":
    return _Bisector.Handle_Bisector_BisecAna_IsNull(t)

def Handle_Bisector_BisecCC_Create() -> "opencascade::handle< Bisector_BisecCC >":
    return _Bisector.Handle_Bisector_BisecCC_Create()

def Handle_Bisector_BisecCC_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Bisector_BisecCC >":
    return _Bisector.Handle_Bisector_BisecCC_DownCast(t)

def Handle_Bisector_BisecCC_IsNull(t: "opencascade::handle< Bisector_BisecCC > const &") -> "bool":
    return _Bisector.Handle_Bisector_BisecCC_IsNull(t)

def Handle_Bisector_BisecPC_Create() -> "opencascade::handle< Bisector_BisecPC >":
    return _Bisector.Handle_Bisector_BisecPC_Create()

def Handle_Bisector_BisecPC_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Bisector_BisecPC >":
    return _Bisector.Handle_Bisector_BisecPC_DownCast(t)

def Handle_Bisector_BisecPC_IsNull(t: "opencascade::handle< Bisector_BisecPC > const &") -> "bool":
    return _Bisector.Handle_Bisector_BisecPC_IsNull(t)
class bisector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def IsConvex(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        Cu: Geom2d_Curve
        Sign: float

        Returns
        -------
        bool

        """
        return _Bisector.bisector_IsConvex(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _Bisector.bisector_swiginit(self, _Bisector.new_bisector())
    __swig_destroy__ = _Bisector.delete_bisector

# Register bisector in _Bisector:
_Bisector.bisector_swigregister(bisector)

def bisector_IsConvex(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    Cu: Geom2d_Curve
    Sign: float

    Returns
    -------
    bool

    """
    return _Bisector.bisector_IsConvex(*args)

class Bisector_Bisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _Bisector.Bisector_Bisec_swiginit(self, _Bisector.new_Bisector_Bisec(*args))

    def ChangeValue(self, *args) -> "opencascade::handle< Geom2d_TrimmedCurve > const &":
        r"""
        Returns the curve of <self>.

        Returns
        -------
        opencascade::handle<Geom2d_TrimmedCurve>

        """
        return _Bisector.Bisector_Bisec_ChangeValue(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Performs the bisecting line between the curves <cu1> and <cu2>. <oncurve> is true if the point <p> is common to <cu1> and <cu2>.

        Parameters
        ----------
        Cu1: Geom2d_Curve
        Cu2: Geom2d_Curve
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        Sense: float
        ajointype: GeomAbs_JoinType
        Tolerance: float
        oncurve: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Performs the bisecting line between the curve <cu1> and the point <pnt>. <oncurve> is true if the point <p> is the point <pnt>.

        Parameters
        ----------
        Cu: Geom2d_Curve
        Pnt: Geom2d_Point
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        Sense: float
        Tolerance: float
        oncurve: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Performs the bisecting line between the curve <cu> and the point <pnt>. <oncurve> is true if the point <p> is the point <pnt>.

        Parameters
        ----------
        Pnt: Geom2d_Point
        Cu: Geom2d_Curve
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        Sense: float
        Tolerance: float
        oncurve: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Performs the bisecting line between the two points <pnt1> and <pnt2>.

        Parameters
        ----------
        Pnt1: Geom2d_Point
        Pnt2: Geom2d_Point
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        Sense: float
        Tolerance: float,optional
        	default value is 0.0
        oncurve: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _Bisector.Bisector_Bisec_Perform(self, *args)

    def Value(self, *args) -> "opencascade::handle< Geom2d_TrimmedCurve > const &":
        r"""
        Returns the curve of <self>.

        Returns
        -------
        opencascade::handle<Geom2d_TrimmedCurve>

        """
        return _Bisector.Bisector_Bisec_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Bisector.delete_Bisector_Bisec

# Register Bisector_Bisec in _Bisector:
_Bisector.Bisector_Bisec_swigregister(Bisector_Bisec)

class Bisector_Curve(OCC.Core.Geom2d.Geom2d_Curve):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def IntervalFirst(self, *args) -> "Standard_Real":
        r"""
        Returns the first parameter of the current interval.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _Bisector.Bisector_Curve_IntervalFirst(self, *args)

    def IntervalLast(self, *args) -> "Standard_Real":
        r"""
        Returns the last parameter of the current interval.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _Bisector.Bisector_Curve_IntervalLast(self, *args)

    def IsExtendAtEnd(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Bisector.Bisector_Curve_IsExtendAtEnd(self, *args)

    def IsExtendAtStart(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Bisector.Bisector_Curve_IsExtendAtStart(self, *args)

    def NbIntervals(self, *args) -> "Standard_Integer":
        r"""
        If necessary, breaks the curve in intervals of continuity <c1>. and returns the number of intervals.

        Returns
        -------
        int

        """
        return _Bisector.Bisector_Curve_NbIntervals(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt2d

        Returns
        -------
        float

        """
        return _Bisector.Bisector_Curve_Parameter(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Bisector_Curve_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Bisector.delete_Bisector_Curve

# Register Bisector_Curve in _Bisector:
_Bisector.Bisector_Curve_swigregister(Bisector_Curve)

class Bisector_FunctionH(OCC.Core.math.math_FunctionWithDerivative):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C2: Geom2d_Curve
        P1: gp_Pnt2d
        T1: gp_Vec2d

        Returns
        -------
        None

        """
        _Bisector.Bisector_FunctionH_swiginit(self, _Bisector.new_Bisector_FunctionH(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _Bisector.delete_Bisector_FunctionH

# Register Bisector_FunctionH in _Bisector:
_Bisector.Bisector_FunctionH_swigregister(Bisector_FunctionH)

class Bisector_FunctionInter(OCC.Core.math.math_FunctionWithDerivative):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Curve
        Bis1: Bisector_Curve
        Bis2: Bisector_Curve

        Returns
        -------
        None

        """
        _Bisector.Bisector_FunctionInter_swiginit(self, _Bisector.new_Bisector_FunctionInter(*args))

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Curve
        Bis1: Bisector_Curve
        Bis2: Bisector_Curve

        Returns
        -------
        None

        """
        return _Bisector.Bisector_FunctionInter_Perform(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Bisector.delete_Bisector_FunctionInter

# Register Bisector_FunctionInter in _Bisector:
_Bisector.Bisector_FunctionInter_swigregister(Bisector_FunctionInter)

class Bisector_Inter(OCC.Core.IntRes2d.IntRes2d_Intersection):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Intersection between 2 curves. c1 separates the element a and b. c2 separates the elements c et d. if b an c have the same geometry. <comunelement> has to be true. it permits an optimiztion of the computation.

        Parameters
        ----------
        C1: Bisector_Bisec
        D1: IntRes2d_Domain
        C2: Bisector_Bisec
        D2: IntRes2d_Domain
        TolConf: float
        Tol: float
        ComunElement: bool

        Returns
        -------
        None

        """
        _Bisector.Bisector_Inter_swiginit(self, _Bisector.new_Bisector_Inter(*args))

    def Perform(self, *args) -> "void":
        r"""
        Intersection between 2 curves. c1 separates the element a and b. c2 separates the elements c et d. if b an c have the same geometry. <comunelement> has to be true. it permits an optimiztion of the computation.

        Parameters
        ----------
        C1: Bisector_Bisec
        D1: IntRes2d_Domain
        C2: Bisector_Bisec
        D2: IntRes2d_Domain
        TolConf: float
        Tol: float
        ComunElement: bool

        Returns
        -------
        None

        """
        return _Bisector.Bisector_Inter_Perform(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Bisector.delete_Bisector_Inter

# Register Bisector_Inter in _Bisector:
_Bisector.Bisector_Inter_swigregister(Bisector_Inter)

class Bisector_PointOnBis(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Param1: float
        Param2: float
        ParamBis: float
        Distance: float
        Point: gp_Pnt2d

        Returns
        -------
        None

        """
        _Bisector.Bisector_PointOnBis_swiginit(self, _Bisector.new_Bisector_PointOnBis(*args))

    def Distance(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        Distance: float

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        float

        """
        return _Bisector.Bisector_PointOnBis_Distance(self, *args)

    def Dump(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _Bisector.Bisector_PointOnBis_Dump(self, *args)

    def IsInfinite(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        Infinite: bool

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        bool

        """
        return _Bisector.Bisector_PointOnBis_IsInfinite(self, *args)

    def ParamOnBis(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        Param: float

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        float

        """
        return _Bisector.Bisector_PointOnBis_ParamOnBis(self, *args)

    def ParamOnC1(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        Param: float

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        float

        """
        return _Bisector.Bisector_PointOnBis_ParamOnC1(self, *args)

    def ParamOnC2(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        Param: float

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        float

        """
        return _Bisector.Bisector_PointOnBis_ParamOnC2(self, *args)

    def Point(self, *args) -> "gp_Pnt2d":
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt2d

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        gp_Pnt2d

        """
        return _Bisector.Bisector_PointOnBis_Point(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Bisector.delete_Bisector_PointOnBis

# Register Bisector_PointOnBis in _Bisector:
_Bisector.Bisector_PointOnBis_swigregister(Bisector_PointOnBis)

class Bisector_PolyBis(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _Bisector.Bisector_PolyBis_swiginit(self, _Bisector.new_Bisector_PolyBis(*args))

    def Append(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Point: Bisector_PointOnBis

        Returns
        -------
        None

        """
        return _Bisector.Bisector_PolyBis_Append(self, *args)

    def First(self, *args) -> "Bisector_PointOnBis const &":
        r"""
        No available documentation.

        Returns
        -------
        Bisector_PointOnBis

        """
        return _Bisector.Bisector_PolyBis_First(self, *args)

    def Interval(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float

        Returns
        -------
        int

        """
        return _Bisector.Bisector_PolyBis_Interval(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Bisector.Bisector_PolyBis_IsEmpty(self, *args)

    def Last(self, *args) -> "Bisector_PointOnBis const &":
        r"""
        No available documentation.

        Returns
        -------
        Bisector_PointOnBis

        """
        return _Bisector.Bisector_PolyBis_Last(self, *args)

    def Length(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Bisector.Bisector_PolyBis_Length(self, *args)

    def Transform(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        T: gp_Trsf2d

        Returns
        -------
        None

        """
        return _Bisector.Bisector_PolyBis_Transform(self, *args)

    def Value(self, *args) -> "Bisector_PointOnBis const &":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        Bisector_PointOnBis

        """
        return _Bisector.Bisector_PolyBis_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Bisector.delete_Bisector_PolyBis

# Register Bisector_PolyBis in _Bisector:
_Bisector.Bisector_PolyBis_swigregister(Bisector_PolyBis)

class Bisector_BisecAna(Bisector_Curve):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _Bisector.Bisector_BisecAna_swiginit(self, _Bisector.new_Bisector_BisecAna(*args))

    def Dump(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Deep: int,optional
        	default value is 0
        Offset: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        return _Bisector.Bisector_BisecAna_Dump(self, *args)

    def Geom2dCurve(self, *args) -> "opencascade::handle< Geom2d_Curve >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _Bisector.Bisector_BisecAna_Geom2dCurve(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        bisector: Geom2d_TrimmedCurve

        Returns
        -------
        None

        """
        return _Bisector.Bisector_BisecAna_Init(self, *args)

    def ParameterOfEndPoint(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Bisector.Bisector_BisecAna_ParameterOfEndPoint(self, *args)

    def ParameterOfStartPoint(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Bisector.Bisector_BisecAna_ParameterOfStartPoint(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Performs the bisecting line between the curves <cu1> and <cu2>. <oncurve> is true if the point <p> is common to <cu1> and <cu2>.

        Parameters
        ----------
        Cu1: Geom2d_Curve
        Cu2: Geom2d_Curve
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        Sense: float
        jointype: GeomAbs_JoinType
        Tolerance: float
        oncurve: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Performs the bisecting line between the curve <cu1> and the point <pnt>. <oncurve> is true if the point <p> is the point <pnt>.

        Parameters
        ----------
        Cu: Geom2d_Curve
        Pnt: Geom2d_Point
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        Sense: float
        Tolerance: float
        oncurve: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Performs the bisecting line between the curve <cu> and the point <pnt>. <oncurve> is true if the point <p> is the point <pnt>.

        Parameters
        ----------
        Pnt: Geom2d_Point
        Cu: Geom2d_Curve
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        Sense: float
        Tolerance: float
        oncurve: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Performs the bisecting line between the two points <pnt1> and <pnt2>.

        Parameters
        ----------
        Pnt1: Geom2d_Point
        Pnt2: Geom2d_Point
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        Sense: float
        Tolerance: float,optional
        	default value is 0.0
        oncurve: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _Bisector.Bisector_BisecAna_Perform(self, *args)

    def SetTrim(self, *args) -> "void":
        r"""
        Trim <self> by a domain defined by the curve <cu>. this domain is the set of the points which are nearest from <cu> than the extremitis of <cu>.

        Parameters
        ----------
        Cu: Geom2d_Curve

        Returns
        -------
        None
        Trim <self> by a domain defined by uf and ul.

        Parameters
        ----------
        uf: float
        ul: float

        Returns
        -------
        None

        """
        return _Bisector.Bisector_BisecAna_SetTrim(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Bisector_BisecAna_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Bisector.delete_Bisector_BisecAna

# Register Bisector_BisecAna in _Bisector:
_Bisector.Bisector_BisecAna_swigregister(Bisector_BisecAna)

class Bisector_BisecCC(Bisector_Curve):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Constructs the bisector between the curves <cu1> and <cu2>. //! <side1> (resp <side2>) = 1 if the bisector curve is on the left of <cu1> (resp <cu2>) else <side1> (resp <side2>) = -1. //! the bisector is trimmed by the point <origin>. <distmax> is used to trim the bisector.the distance between the points of the bisector and <cu> is smaller than <distmax>.

        Parameters
        ----------
        Cu1: Geom2d_Curve
        Cu2: Geom2d_Curve
        Side1: float
        Side2: float
        Origin: gp_Pnt2d
        DistMax: float,optional
        	default value is 500

        Returns
        -------
        None

        """
        _Bisector.Bisector_BisecCC_swiginit(self, _Bisector.new_Bisector_BisecCC(*args))

    def ChangeGuide(self, *args) -> "opencascade::handle< Bisector_BisecCC >":
        r"""
        The parameter on <self> is linked to the parameter on the first curve. this method creates the same bisector where the curves are inversed.

        Returns
        -------
        opencascade::handle<Bisector_BisecCC>

        """
        return _Bisector.Bisector_BisecCC_ChangeGuide(self, *args)

    def Curve(self, *args) -> "opencascade::handle< Geom2d_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        IndCurve: int

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _Bisector.Bisector_BisecCC_Curve(self, *args)

    def Dump(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Deep: int,optional
        	default value is 0
        Offset: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        return _Bisector.Bisector_BisecCC_Dump(self, *args)

    def IntervalContinuity(self, *args) -> "GeomAbs_Shape":
        r"""
        No available documentation.

        Returns
        -------
        GeomAbs_Shape

        """
        return _Bisector.Bisector_BisecCC_IntervalContinuity(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Bisector.Bisector_BisecCC_IsEmpty(self, *args)

    def LinkBisCurve(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the curve1 of the projection of the point of parameter u on <self>.

        Parameters
        ----------
        U: float

        Returns
        -------
        float

        """
        return _Bisector.Bisector_BisecCC_LinkBisCurve(self, *args)

    def LinkCurveBis(self, *args) -> "Standard_Real":
        r"""
        Returns the reciproque of linkbiscurve.

        Parameters
        ----------
        U: float

        Returns
        -------
        float

        """
        return _Bisector.Bisector_BisecCC_LinkCurveBis(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Computes the bisector between the curves <cu1> and <cu2>. //! <side1> (resp <side2>) = 1 if the bisector curve is on the left of <cu1> (resp <cu2>) else <side1> (resp <side2>) = -1. //! the bisector is trimmed by the point <origin>. //! <distmax> is used to trim the bisector.the distance between the points of the bisector and <cu> is smaller than <distmax>.

        Parameters
        ----------
        Cu1: Geom2d_Curve
        Cu2: Geom2d_Curve
        Side1: float
        Side2: float
        Origin: gp_Pnt2d
        DistMax: float,optional
        	default value is 500

        Returns
        -------
        None

        """
        return _Bisector.Bisector_BisecCC_Perform(self, *args)

    def Polygon(self, *args) -> "Bisector_PolyBis const &":
        r"""
        No available documentation.

        Returns
        -------
        Bisector_PolyBis

        """
        return _Bisector.Bisector_BisecCC_Polygon(self, *args)

    def ValueAndDist(self, *args) -> "gp_Pnt2d":
        r"""
        Returns the point of parameter u. computes the distance between the current point and the two curves i separate. computes the parameters on each curve corresponding of the projection of the current point.

        Parameters
        ----------
        U: float

        Returns
        -------
        U1: float
        U2: float
        Distance: float

        """
        return _Bisector.Bisector_BisecCC_ValueAndDist(self, *args)

    def ValueByInt(self, *args) -> "gp_Pnt2d":
        r"""
        Returns the point of parameter u. computes the distance between the current point and the two curves i separate. computes the parameters on each curve corresponding of the projection of the current point.

        Parameters
        ----------
        U: float

        Returns
        -------
        U1: float
        U2: float
        Distance: float

        """
        return _Bisector.Bisector_BisecCC_ValueByInt(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Bisector_BisecCC_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Bisector.delete_Bisector_BisecCC

# Register Bisector_BisecCC in _Bisector:
_Bisector.Bisector_BisecCC_swigregister(Bisector_BisecCC)

class Bisector_BisecPC(Bisector_Curve):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Constructs the bisector between the point <p> and the curve <cu>. <side> = 1. if the bisector curve is on the left of <cu> else <side> = -1. <distmax> is used to trim the bisector.the distance between the points of the bisector and <cu> is smaller than <distmax>.

        Parameters
        ----------
        Cu: Geom2d_Curve
        P: gp_Pnt2d
        Side: float
        DistMax: float,optional
        	default value is 500

        Returns
        -------
        None
        Constructs the bisector between the point <p> and the curve <cu> trimmed by <umin> and <umax> <side> = 1. if the bisector curve is on the left of <cu> else <side> = -1. warning: the bisector is supposed all over defined between <umin> and <umax>.

        Parameters
        ----------
        Cu: Geom2d_Curve
        P: gp_Pnt2d
        Side: float
        UMin: float
        UMax: float

        Returns
        -------
        None

        """
        _Bisector.Bisector_BisecPC_swiginit(self, _Bisector.new_Bisector_BisecPC(*args))

    def Distance(self, *args) -> "Standard_Real":
        r"""
        Returns the distance between the point of parameter u on <self> and my point or my curve.

        Parameters
        ----------
        U: float

        Returns
        -------
        float

        """
        return _Bisector.Bisector_BisecPC_Distance(self, *args)

    def Dump(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Deep: int,optional
        	default value is 0
        Offset: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        return _Bisector.Bisector_BisecPC_Dump(self, *args)

    def IntervalContinuity(self, *args) -> "GeomAbs_Shape":
        r"""
        No available documentation.

        Returns
        -------
        GeomAbs_Shape

        """
        return _Bisector.Bisector_BisecPC_IntervalContinuity(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        Returns <true> if the bisector is empty.

        Returns
        -------
        bool

        """
        return _Bisector.Bisector_BisecPC_IsEmpty(self, *args)

    def LinkBisCurve(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the curve1 of the projection of the point of parameter u on <self>.

        Parameters
        ----------
        U: float

        Returns
        -------
        float

        """
        return _Bisector.Bisector_BisecPC_LinkBisCurve(self, *args)

    def LinkCurveBis(self, *args) -> "Standard_Real":
        r"""
        Returns the reciproque of linkbiscurve.

        Parameters
        ----------
        U: float

        Returns
        -------
        float

        """
        return _Bisector.Bisector_BisecPC_LinkCurveBis(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Construct the bisector between the point <p> and the curve <cu>. <side> = 1. if the bisector curve is on the left of <cu> else <side> = -1. <distmax> is used to trim the bisector.the distance between the points of the bisector and <cu> is smaller than <distmax>.

        Parameters
        ----------
        Cu: Geom2d_Curve
        P: gp_Pnt2d
        Side: float
        DistMax: float,optional
        	default value is 500

        Returns
        -------
        None

        """
        return _Bisector.Bisector_BisecPC_Perform(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Bisector_BisecPC_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Bisector.delete_Bisector_BisecPC

# Register Bisector_BisecPC in _Bisector:
_Bisector.Bisector_BisecPC_swigregister(Bisector_BisecPC)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.TColgp import *
from OCC.Core.Quantity import *
from OCC.Core.gp import *
from OCC.Core.TCollection import *


class Vrml_VertexOrdering(IntEnum):
	Vrml_UNKNOWN_ORDERING: int = ...
	Vrml_CLOCKWISE: int = ...
	Vrml_COUNTERCLOCKWISE: int = ...
Vrml_UNKNOWN_ORDERING = Vrml_VertexOrdering.Vrml_UNKNOWN_ORDERING
Vrml_CLOCKWISE = Vrml_VertexOrdering.Vrml_CLOCKWISE
Vrml_COUNTERCLOCKWISE = Vrml_VertexOrdering.Vrml_COUNTERCLOCKWISE

class Vrml_FontStyleFamily(IntEnum):
	Vrml_SERIF: int = ...
	Vrml_SANS: int = ...
	Vrml_TYPEWRITER: int = ...
Vrml_SERIF = Vrml_FontStyleFamily.Vrml_SERIF
Vrml_SANS = Vrml_FontStyleFamily.Vrml_SANS
Vrml_TYPEWRITER = Vrml_FontStyleFamily.Vrml_TYPEWRITER

class Vrml_SeparatorRenderCulling(IntEnum):
	Vrml_OFF: int = ...
	Vrml_ON: int = ...
	Vrml_AUTO: int = ...
Vrml_OFF = Vrml_SeparatorRenderCulling.Vrml_OFF
Vrml_ON = Vrml_SeparatorRenderCulling.Vrml_ON
Vrml_AUTO = Vrml_SeparatorRenderCulling.Vrml_AUTO

class Vrml_Texture2Wrap(IntEnum):
	Vrml_REPEAT: int = ...
	Vrml_CLAMP: int = ...
Vrml_REPEAT = Vrml_Texture2Wrap.Vrml_REPEAT
Vrml_CLAMP = Vrml_Texture2Wrap.Vrml_CLAMP

class Vrml_FaceType(IntEnum):
	Vrml_UNKNOWN_FACE_TYPE: int = ...
	Vrml_CONVEX: int = ...
Vrml_UNKNOWN_FACE_TYPE = Vrml_FaceType.Vrml_UNKNOWN_FACE_TYPE
Vrml_CONVEX = Vrml_FaceType.Vrml_CONVEX

class Vrml_AsciiTextJustification(IntEnum):
	Vrml_LEFT: int = ...
	Vrml_CENTER: int = ...
	Vrml_RIGHT: int = ...
Vrml_LEFT = Vrml_AsciiTextJustification.Vrml_LEFT
Vrml_CENTER = Vrml_AsciiTextJustification.Vrml_CENTER
Vrml_RIGHT = Vrml_AsciiTextJustification.Vrml_RIGHT

class Vrml_ConeParts(IntEnum):
	Vrml_ConeSIDES: int = ...
	Vrml_ConeBOTTOM: int = ...
	Vrml_ConeALL: int = ...
Vrml_ConeSIDES = Vrml_ConeParts.Vrml_ConeSIDES
Vrml_ConeBOTTOM = Vrml_ConeParts.Vrml_ConeBOTTOM
Vrml_ConeALL = Vrml_ConeParts.Vrml_ConeALL

class Vrml_SFImageNumber(IntEnum):
	Vrml_NULL: int = ...
	Vrml_ONE: int = ...
	Vrml_TWO: int = ...
	Vrml_THREE: int = ...
	Vrml_FOUR: int = ...
Vrml_NULL = Vrml_SFImageNumber.Vrml_NULL
Vrml_ONE = Vrml_SFImageNumber.Vrml_ONE
Vrml_TWO = Vrml_SFImageNumber.Vrml_TWO
Vrml_THREE = Vrml_SFImageNumber.Vrml_THREE
Vrml_FOUR = Vrml_SFImageNumber.Vrml_FOUR

class Vrml_MaterialBindingAndNormalBinding(IntEnum):
	Vrml_DEFAULT: int = ...
	Vrml_OVERALL: int = ...
	Vrml_PER_PART: int = ...
	Vrml_PER_PART_INDEXED: int = ...
	Vrml_PER_FACE: int = ...
	Vrml_PER_FACE_INDEXED: int = ...
	Vrml_PER_VERTEX: int = ...
	Vrml_PER_VERTEX_INDEXED: int = ...
Vrml_DEFAULT = Vrml_MaterialBindingAndNormalBinding.Vrml_DEFAULT
Vrml_OVERALL = Vrml_MaterialBindingAndNormalBinding.Vrml_OVERALL
Vrml_PER_PART = Vrml_MaterialBindingAndNormalBinding.Vrml_PER_PART
Vrml_PER_PART_INDEXED = Vrml_MaterialBindingAndNormalBinding.Vrml_PER_PART_INDEXED
Vrml_PER_FACE = Vrml_MaterialBindingAndNormalBinding.Vrml_PER_FACE
Vrml_PER_FACE_INDEXED = Vrml_MaterialBindingAndNormalBinding.Vrml_PER_FACE_INDEXED
Vrml_PER_VERTEX = Vrml_MaterialBindingAndNormalBinding.Vrml_PER_VERTEX
Vrml_PER_VERTEX_INDEXED = Vrml_MaterialBindingAndNormalBinding.Vrml_PER_VERTEX_INDEXED

class Vrml_ShapeType(IntEnum):
	Vrml_UNKNOWN_SHAPE_TYPE: int = ...
	Vrml_SOLID: int = ...
Vrml_UNKNOWN_SHAPE_TYPE = Vrml_ShapeType.Vrml_UNKNOWN_SHAPE_TYPE
Vrml_SOLID = Vrml_ShapeType.Vrml_SOLID

class Vrml_WWWAnchorMap(IntEnum):
	Vrml_MAP_NONE: int = ...
	Vrml_POINT: int = ...
Vrml_MAP_NONE = Vrml_WWWAnchorMap.Vrml_MAP_NONE
Vrml_POINT = Vrml_WWWAnchorMap.Vrml_POINT

class Vrml_CylinderParts(IntEnum):
	Vrml_CylinderSIDES: int = ...
	Vrml_CylinderTOP: int = ...
	Vrml_CylinderBOTTOM: int = ...
	Vrml_CylinderALL: int = ...
Vrml_CylinderSIDES = Vrml_CylinderParts.Vrml_CylinderSIDES
Vrml_CylinderTOP = Vrml_CylinderParts.Vrml_CylinderTOP
Vrml_CylinderBOTTOM = Vrml_CylinderParts.Vrml_CylinderBOTTOM
Vrml_CylinderALL = Vrml_CylinderParts.Vrml_CylinderALL

class Vrml_FontStyleStyle(IntEnum):
	Vrml_NONE: int = ...
	Vrml_BOLD: int = ...
	Vrml_ITALIC: int = ...
Vrml_NONE = Vrml_FontStyleStyle.Vrml_NONE
Vrml_BOLD = Vrml_FontStyleStyle.Vrml_BOLD
Vrml_ITALIC = Vrml_FontStyleStyle.Vrml_ITALIC

class vrml:
	pass

class Vrml_AsciiText(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aString: TColStd_HArray1OfAsciiString, aSpacing: float, aJustification: Vrml_AsciiTextJustification, aWidth: float) -> None: ...
	def Justification(self) -> Vrml_AsciiTextJustification: ...
	def SetJustification(self, aJustification: Vrml_AsciiTextJustification) -> None: ...
	def SetSpacing(self, aSpacing: float) -> None: ...
	def SetString(self, aString: TColStd_HArray1OfAsciiString) -> None: ...
	def SetWidth(self, aWidth: float) -> None: ...
	def Spacing(self) -> float: ...
	def String(self) -> TColStd_HArray1OfAsciiString: ...
	def Width(self) -> float: ...

class Vrml_Cone:
	def __init__(self, aParts: Optional[Vrml_ConeParts] = Vrml_ConeALL, aBottomRadius: Optional[float] = 1, aHeight: Optional[float] = 2) -> None: ...
	def BottomRadius(self) -> float: ...
	def Height(self) -> float: ...
	def Parts(self) -> Vrml_ConeParts: ...
	def SetBottomRadius(self, aBottomRadius: float) -> None: ...
	def SetHeight(self, aHeight: float) -> None: ...
	def SetParts(self, aParts: Vrml_ConeParts) -> None: ...

class Vrml_Coordinate3(Standard_Transient):
	@overload
	def __init__(self, aPoint: TColgp_HArray1OfVec) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def Point(self) -> TColgp_HArray1OfVec: ...
	def SetPoint(self, aPoint: TColgp_HArray1OfVec) -> None: ...

class Vrml_Cube:
	def __init__(self, aWidth: Optional[float] = 2, aHeight: Optional[float] = 2, aDepth: Optional[float] = 2) -> None: ...
	def Depth(self) -> float: ...
	def Height(self) -> float: ...
	def SetDepth(self, aDepth: float) -> None: ...
	def SetHeight(self, aHeight: float) -> None: ...
	def SetWidth(self, aWidth: float) -> None: ...
	def Width(self) -> float: ...

class Vrml_Cylinder:
	def __init__(self, aParts: Optional[Vrml_CylinderParts] = Vrml_CylinderALL, aRadius: Optional[float] = 1, aHeight: Optional[float] = 2) -> None: ...
	def Height(self) -> float: ...
	def Parts(self) -> Vrml_CylinderParts: ...
	def Radius(self) -> float: ...
	def SetHeight(self, aHeight: float) -> None: ...
	def SetParts(self, aParts: Vrml_CylinderParts) -> None: ...
	def SetRadius(self, aRadius: float) -> None: ...

class Vrml_DirectionalLight:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aOnOff: bool, aIntensity: float, aColor: Quantity_Color, aDirection: gp_Vec) -> None: ...
	def Color(self) -> Quantity_Color: ...
	def Direction(self) -> gp_Vec: ...
	def Intensity(self) -> float: ...
	def OnOff(self) -> bool: ...
	def SetColor(self, aColor: Quantity_Color) -> None: ...
	def SetDirection(self, aDirection: gp_Vec) -> None: ...
	def SetIntensity(self, aIntensity: float) -> None: ...
	def SetOnOff(self, aOnOff: bool) -> None: ...

class Vrml_FontStyle:
	def __init__(self, aSize: Optional[float] = 10, aFamily: Optional[Vrml_FontStyleFamily] = Vrml_SERIF, aStyle: Optional[Vrml_FontStyleStyle] = Vrml_NONE) -> None: ...
	def Family(self) -> Vrml_FontStyleFamily: ...
	def SetFamily(self, aFamily: Vrml_FontStyleFamily) -> None: ...
	def SetSize(self, aSize: float) -> None: ...
	def SetStyle(self, aStyle: Vrml_FontStyleStyle) -> None: ...
	def Size(self) -> float: ...
	def Style(self) -> Vrml_FontStyleStyle: ...

class Vrml_Group:
	def __init__(self) -> None: ...

class Vrml_IndexedFaceSet(Standard_Transient):
	@overload
	def __init__(self, aCoordIndex: TColStd_HArray1OfInteger, aMaterialIndex: TColStd_HArray1OfInteger, aNormalIndex: TColStd_HArray1OfInteger, aTextureCoordIndex: TColStd_HArray1OfInteger) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def CoordIndex(self) -> TColStd_HArray1OfInteger: ...
	def MaterialIndex(self) -> TColStd_HArray1OfInteger: ...
	def NormalIndex(self) -> TColStd_HArray1OfInteger: ...
	def SetCoordIndex(self, aCoordIndex: TColStd_HArray1OfInteger) -> None: ...
	def SetMaterialIndex(self, aMaterialIndex: TColStd_HArray1OfInteger) -> None: ...
	def SetNormalIndex(self, aNormalIndex: TColStd_HArray1OfInteger) -> None: ...
	def SetTextureCoordIndex(self, aTextureCoordIndex: TColStd_HArray1OfInteger) -> None: ...
	def TextureCoordIndex(self) -> TColStd_HArray1OfInteger: ...

class Vrml_IndexedLineSet(Standard_Transient):
	@overload
	def __init__(self, aCoordIndex: TColStd_HArray1OfInteger, aMaterialIndex: TColStd_HArray1OfInteger, aNormalIndex: TColStd_HArray1OfInteger, aTextureCoordIndex: TColStd_HArray1OfInteger) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def CoordIndex(self) -> TColStd_HArray1OfInteger: ...
	def MaterialIndex(self) -> TColStd_HArray1OfInteger: ...
	def NormalIndex(self) -> TColStd_HArray1OfInteger: ...
	def SetCoordIndex(self, aCoordIndex: TColStd_HArray1OfInteger) -> None: ...
	def SetMaterialIndex(self, aMaterialIndex: TColStd_HArray1OfInteger) -> None: ...
	def SetNormalIndex(self, aNormalIndex: TColStd_HArray1OfInteger) -> None: ...
	def SetTextureCoordIndex(self, aTextureCoordIndex: TColStd_HArray1OfInteger) -> None: ...
	def TextureCoordIndex(self) -> TColStd_HArray1OfInteger: ...

class Vrml_Info:
	def __init__(self, aString: Optional[TCollection_AsciiString] = "<Undefinedinfo>") -> None: ...
	def SetString(self, aString: TCollection_AsciiString) -> None: ...
	def String(self) -> TCollection_AsciiString: ...

class Vrml_Instancing:
	def __init__(self, aString: TCollection_AsciiString) -> None: ...

class Vrml_LOD(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aRange: TColStd_HArray1OfReal, aCenter: gp_Vec) -> None: ...
	def Center(self) -> gp_Vec: ...
	def Range(self) -> TColStd_HArray1OfReal: ...
	def SetCenter(self, aCenter: gp_Vec) -> None: ...
	def SetRange(self, aRange: TColStd_HArray1OfReal) -> None: ...

class Vrml_Material(Standard_Transient):
	@overload
	def __init__(self, aAmbientColor: Quantity_HArray1OfColor, aDiffuseColor: Quantity_HArray1OfColor, aSpecularColor: Quantity_HArray1OfColor, aEmissiveColor: Quantity_HArray1OfColor, aShininess: TColStd_HArray1OfReal, aTransparency: TColStd_HArray1OfReal) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def AmbientColor(self) -> Quantity_HArray1OfColor: ...
	def DiffuseColor(self) -> Quantity_HArray1OfColor: ...
	def EmissiveColor(self) -> Quantity_HArray1OfColor: ...
	def SetAmbientColor(self, aAmbientColor: Quantity_HArray1OfColor) -> None: ...
	def SetDiffuseColor(self, aDiffuseColor: Quantity_HArray1OfColor) -> None: ...
	def SetEmissiveColor(self, aEmissiveColor: Quantity_HArray1OfColor) -> None: ...
	def SetShininess(self, aShininess: TColStd_HArray1OfReal) -> None: ...
	def SetSpecularColor(self, aSpecularColor: Quantity_HArray1OfColor) -> None: ...
	def SetTransparency(self, aTransparency: TColStd_HArray1OfReal) -> None: ...
	def Shininess(self) -> TColStd_HArray1OfReal: ...
	def SpecularColor(self) -> Quantity_HArray1OfColor: ...
	def Transparency(self) -> TColStd_HArray1OfReal: ...

class Vrml_MaterialBinding:
	@overload
	def __init__(self, aValue: Vrml_MaterialBindingAndNormalBinding) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def SetValue(self, aValue: Vrml_MaterialBindingAndNormalBinding) -> None: ...
	def Value(self) -> Vrml_MaterialBindingAndNormalBinding: ...

class Vrml_MatrixTransform:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aMatrix: gp_Trsf) -> None: ...
	def Matrix(self) -> gp_Trsf: ...
	def SetMatrix(self, aMatrix: gp_Trsf) -> None: ...

class Vrml_Normal(Standard_Transient):
	@overload
	def __init__(self, aVector: TColgp_HArray1OfVec) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def SetVector(self, aVector: TColgp_HArray1OfVec) -> None: ...
	def Vector(self) -> TColgp_HArray1OfVec: ...

class Vrml_NormalBinding:
	@overload
	def __init__(self, aValue: Vrml_MaterialBindingAndNormalBinding) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def SetValue(self, aValue: Vrml_MaterialBindingAndNormalBinding) -> None: ...
	def Value(self) -> Vrml_MaterialBindingAndNormalBinding: ...

class Vrml_OrthographicCamera:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aPosition: gp_Vec, aOrientation: Vrml_SFRotation, aFocalDistance: float, aHeight: float) -> None: ...
	def FocalDistance(self) -> float: ...
	def Height(self) -> float: ...
	def Orientation(self) -> Vrml_SFRotation: ...
	def Position(self) -> gp_Vec: ...
	def SetFocalDistance(self, aFocalDistance: float) -> None: ...
	def SetHeight(self, aHeight: float) -> None: ...
	def SetOrientation(self, aOrientation: Vrml_SFRotation) -> None: ...
	def SetPosition(self, aPosition: gp_Vec) -> None: ...

class Vrml_PerspectiveCamera:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aPosition: gp_Vec, aOrientation: Vrml_SFRotation, aFocalDistance: float, aHeightAngle: float) -> None: ...
	def Angle(self) -> float: ...
	def FocalDistance(self) -> float: ...
	def Orientation(self) -> Vrml_SFRotation: ...
	def Position(self) -> gp_Vec: ...
	def SetAngle(self, aHeightAngle: float) -> None: ...
	def SetFocalDistance(self, aFocalDistance: float) -> None: ...
	def SetOrientation(self, aOrientation: Vrml_SFRotation) -> None: ...
	def SetPosition(self, aPosition: gp_Vec) -> None: ...

class Vrml_PointLight:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aOnOff: bool, aIntensity: float, aColor: Quantity_Color, aLocation: gp_Vec) -> None: ...
	def Color(self) -> Quantity_Color: ...
	def Intensity(self) -> float: ...
	def Location(self) -> gp_Vec: ...
	def OnOff(self) -> bool: ...
	def SetColor(self, aColor: Quantity_Color) -> None: ...
	def SetIntensity(self, aIntensity: float) -> None: ...
	def SetLocation(self, aLocation: gp_Vec) -> None: ...
	def SetOnOff(self, aOnOff: bool) -> None: ...

class Vrml_PointSet:
	def __init__(self, aStartIndex: Optional[int] = 0, aNumPoints: Optional[int] = -1) -> None: ...
	def NumPoints(self) -> int: ...
	def SetNumPoints(self, aNumPoints: int) -> None: ...
	def SetStartIndex(self, aStartIndex: int) -> None: ...
	def StartIndex(self) -> int: ...

class Vrml_Rotation:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aRotation: Vrml_SFRotation) -> None: ...
	def Rotation(self) -> Vrml_SFRotation: ...
	def SetRotation(self, aRotation: Vrml_SFRotation) -> None: ...

class Vrml_SFImage(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aWidth: int, aHeight: int, aNumber: Vrml_SFImageNumber, anArray: TColStd_HArray1OfInteger) -> None: ...
	def Array(self) -> TColStd_HArray1OfInteger: ...
	def ArrayFlag(self) -> bool: ...
	def Height(self) -> int: ...
	def Number(self) -> Vrml_SFImageNumber: ...
	def SetArray(self, anArray: TColStd_HArray1OfInteger) -> None: ...
	def SetHeight(self, aHeight: int) -> None: ...
	def SetNumber(self, aNumber: Vrml_SFImageNumber) -> None: ...
	def SetWidth(self, aWidth: int) -> None: ...
	def Width(self) -> int: ...

class Vrml_SFRotation:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aRotationX: float, aRotationY: float, aRotationZ: float, anAngle: float) -> None: ...
	def Angle(self) -> float: ...
	def RotationX(self) -> float: ...
	def RotationY(self) -> float: ...
	def RotationZ(self) -> float: ...
	def SetAngle(self, anAngle: float) -> None: ...
	def SetRotationX(self, aRotationX: float) -> None: ...
	def SetRotationY(self, aRotationY: float) -> None: ...
	def SetRotationZ(self, aRotationZ: float) -> None: ...

class Vrml_Scale:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aScaleFactor: gp_Vec) -> None: ...
	def ScaleFactor(self) -> gp_Vec: ...
	def SetScaleFactor(self, aScaleFactor: gp_Vec) -> None: ...

class Vrml_Separator:
	@overload
	def __init__(self, aRenderCulling: Vrml_SeparatorRenderCulling) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def RenderCulling(self) -> Vrml_SeparatorRenderCulling: ...
	def SetRenderCulling(self, aRenderCulling: Vrml_SeparatorRenderCulling) -> None: ...

class Vrml_ShapeHints:
	def __init__(self, aVertexOrdering: Optional[Vrml_VertexOrdering] = Vrml_UNKNOWN_ORDERING, aShapeType: Optional[Vrml_ShapeType] = Vrml_UNKNOWN_SHAPE_TYPE, aFaceType: Optional[Vrml_FaceType] = Vrml_CONVEX, aAngle: Optional[float] = 0.5) -> None: ...
	def Angle(self) -> float: ...
	def FaceType(self) -> Vrml_FaceType: ...
	def SetAngle(self, aAngle: float) -> None: ...
	def SetFaceType(self, aFaceType: Vrml_FaceType) -> None: ...
	def SetShapeType(self, aShapeType: Vrml_ShapeType) -> None: ...
	def SetVertexOrdering(self, aVertexOrdering: Vrml_VertexOrdering) -> None: ...
	def ShapeType(self) -> Vrml_ShapeType: ...
	def VertexOrdering(self) -> Vrml_VertexOrdering: ...

class Vrml_Sphere:
	def __init__(self, aRadius: Optional[float] = 1) -> None: ...
	def Radius(self) -> float: ...
	def SetRadius(self, aRadius: float) -> None: ...

class Vrml_SpotLight:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aOnOff: bool, aIntensity: float, aColor: Quantity_Color, aLocation: gp_Vec, aDirection: gp_Vec, aDropOffRate: float, aCutOffAngle: float) -> None: ...
	def Color(self) -> Quantity_Color: ...
	def CutOffAngle(self) -> float: ...
	def Direction(self) -> gp_Vec: ...
	def DropOffRate(self) -> float: ...
	def Intensity(self) -> float: ...
	def Location(self) -> gp_Vec: ...
	def OnOff(self) -> bool: ...
	def SetColor(self, aColor: Quantity_Color) -> None: ...
	def SetCutOffAngle(self, aCutOffAngle: float) -> None: ...
	def SetDirection(self, aDirection: gp_Vec) -> None: ...
	def SetDropOffRate(self, aDropOffRate: float) -> None: ...
	def SetIntensity(self, aIntensity: float) -> None: ...
	def SetLocation(self, aLocation: gp_Vec) -> None: ...
	def SetOnOff(self, anOnOff: bool) -> None: ...

class Vrml_Switch:
	def __init__(self, aWhichChild: Optional[int] = -1) -> None: ...
	def SetWhichChild(self, aWhichChild: int) -> None: ...
	def WhichChild(self) -> int: ...

class Vrml_Texture2:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aFilename: TCollection_AsciiString, aImage: Vrml_SFImage, aWrapS: Vrml_Texture2Wrap, aWrapT: Vrml_Texture2Wrap) -> None: ...
	def Filename(self) -> TCollection_AsciiString: ...
	def Image(self) -> Vrml_SFImage: ...
	def SetFilename(self, aFilename: TCollection_AsciiString) -> None: ...
	def SetImage(self, aImage: Vrml_SFImage) -> None: ...
	def SetWrapS(self, aWrapS: Vrml_Texture2Wrap) -> None: ...
	def SetWrapT(self, aWrapT: Vrml_Texture2Wrap) -> None: ...
	def WrapS(self) -> Vrml_Texture2Wrap: ...
	def WrapT(self) -> Vrml_Texture2Wrap: ...

class Vrml_Texture2Transform:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aTranslation: gp_Vec2d, aRotation: float, aScaleFactor: gp_Vec2d, aCenter: gp_Vec2d) -> None: ...
	def Center(self) -> gp_Vec2d: ...
	def Rotation(self) -> float: ...
	def ScaleFactor(self) -> gp_Vec2d: ...
	def SetCenter(self, aCenter: gp_Vec2d) -> None: ...
	def SetRotation(self, aRotation: float) -> None: ...
	def SetScaleFactor(self, aScaleFactor: gp_Vec2d) -> None: ...
	def SetTranslation(self, aTranslation: gp_Vec2d) -> None: ...
	def Translation(self) -> gp_Vec2d: ...

class Vrml_TextureCoordinate2(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aPoint: TColgp_HArray1OfVec2d) -> None: ...
	def Point(self) -> TColgp_HArray1OfVec2d: ...
	def SetPoint(self, aPoint: TColgp_HArray1OfVec2d) -> None: ...

class Vrml_Transform:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aTranslation: gp_Vec, aRotation: Vrml_SFRotation, aScaleFactor: gp_Vec, aScaleOrientation: Vrml_SFRotation, aCenter: gp_Vec) -> None: ...
	def Center(self) -> gp_Vec: ...
	def Rotation(self) -> Vrml_SFRotation: ...
	def ScaleFactor(self) -> gp_Vec: ...
	def ScaleOrientation(self) -> Vrml_SFRotation: ...
	def SetCenter(self, aCenter: gp_Vec) -> None: ...
	def SetRotation(self, aRotation: Vrml_SFRotation) -> None: ...
	def SetScaleFactor(self, aScaleFactor: gp_Vec) -> None: ...
	def SetScaleOrientation(self, aScaleOrientation: Vrml_SFRotation) -> None: ...
	def SetTranslation(self, aTranslation: gp_Vec) -> None: ...
	def Translation(self) -> gp_Vec: ...

class Vrml_TransformSeparator:
	def __init__(self) -> None: ...

class Vrml_Translation:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aTranslation: gp_Vec) -> None: ...
	def SetTranslation(self, aTranslation: gp_Vec) -> None: ...
	def Translation(self) -> gp_Vec: ...

class Vrml_WWWAnchor:
	def __init__(self, aName: Optional[TCollection_AsciiString] = "", aDescription: Optional[TCollection_AsciiString] = "", aMap: Optional[Vrml_WWWAnchorMap] = Vrml_MAP_NONE) -> None: ...
	def Description(self) -> TCollection_AsciiString: ...
	def Map(self) -> Vrml_WWWAnchorMap: ...
	def Name(self) -> TCollection_AsciiString: ...
	def SetDescription(self, aDescription: TCollection_AsciiString) -> None: ...
	def SetMap(self, aMap: Vrml_WWWAnchorMap) -> None: ...
	def SetName(self, aName: TCollection_AsciiString) -> None: ...

class Vrml_WWWInline:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aName: TCollection_AsciiString, aBboxSize: gp_Vec, aBboxCenter: gp_Vec) -> None: ...
	def BboxCenter(self) -> gp_Vec: ...
	def BboxSize(self) -> gp_Vec: ...
	def Name(self) -> TCollection_AsciiString: ...
	def SetBboxCenter(self, aBboxCenter: gp_Vec) -> None: ...
	def SetBboxSize(self, aBboxSize: gp_Vec) -> None: ...
	def SetName(self, aName: TCollection_AsciiString) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

vrml_CommentWriter = vrml.CommentWriter



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BinXCAFDrivers module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_binxcafdrivers.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BinXCAFDrivers
else:
    import _BinXCAFDrivers

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BinXCAFDrivers.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BinXCAFDrivers.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinXCAFDrivers.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinXCAFDrivers.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BinXCAFDrivers.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BinXCAFDrivers.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BinXCAFDrivers.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BinXCAFDrivers.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BinXCAFDrivers.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BinXCAFDrivers.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinXCAFDrivers.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BinXCAFDrivers.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BinXCAFDrivers.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinXCAFDrivers.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinXCAFDrivers.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinXCAFDrivers.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BinXCAFDrivers.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BinXCAFDrivers:
_BinXCAFDrivers.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BinXCAFDrivers.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.BinMDF
import OCC.Core.TDF
import OCC.Core.BinObjMgt
import OCC.Core.Storage
import OCC.Core.TDocStd
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.BinDrivers
import OCC.Core.BinLDrivers

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_BinXCAFDrivers_DocumentRetrievalDriver_Create() -> "opencascade::handle< BinXCAFDrivers_DocumentRetrievalDriver >":
    return _BinXCAFDrivers.Handle_BinXCAFDrivers_DocumentRetrievalDriver_Create()

def Handle_BinXCAFDrivers_DocumentRetrievalDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinXCAFDrivers_DocumentRetrievalDriver >":
    return _BinXCAFDrivers.Handle_BinXCAFDrivers_DocumentRetrievalDriver_DownCast(t)

def Handle_BinXCAFDrivers_DocumentRetrievalDriver_IsNull(t: "opencascade::handle< BinXCAFDrivers_DocumentRetrievalDriver > const &") -> "bool":
    return _BinXCAFDrivers.Handle_BinXCAFDrivers_DocumentRetrievalDriver_IsNull(t)

def Handle_BinXCAFDrivers_DocumentStorageDriver_Create() -> "opencascade::handle< BinXCAFDrivers_DocumentStorageDriver >":
    return _BinXCAFDrivers.Handle_BinXCAFDrivers_DocumentStorageDriver_Create()

def Handle_BinXCAFDrivers_DocumentStorageDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinXCAFDrivers_DocumentStorageDriver >":
    return _BinXCAFDrivers.Handle_BinXCAFDrivers_DocumentStorageDriver_DownCast(t)

def Handle_BinXCAFDrivers_DocumentStorageDriver_IsNull(t: "opencascade::handle< BinXCAFDrivers_DocumentStorageDriver > const &") -> "bool":
    return _BinXCAFDrivers.Handle_BinXCAFDrivers_DocumentStorageDriver_IsNull(t)
class binxcafdrivers(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AttributeDrivers(*args) -> "opencascade::handle< BinMDF_ADriverTable >":
        r"""
        Creates the table of drivers of types supported.

        Parameters
        ----------
        MsgDrv: Message_Messenger

        Returns
        -------
        opencascade::handle<BinMDF_ADriverTable>

        """
        return _BinXCAFDrivers.binxcafdrivers_AttributeDrivers(*args)

    @staticmethod
    def DefineFormat(*args) -> "void":
        r"""
        Defines format 'binxcaf' and registers its read and write drivers in the specified application.

        Parameters
        ----------
        theApp: TDocStd_Application

        Returns
        -------
        None

        """
        return _BinXCAFDrivers.binxcafdrivers_DefineFormat(*args)

    @staticmethod
    def Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theGUID: Standard_GUID

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _BinXCAFDrivers.binxcafdrivers_Factory(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BinXCAFDrivers.binxcafdrivers_swiginit(self, _BinXCAFDrivers.new_binxcafdrivers())
    __swig_destroy__ = _BinXCAFDrivers.delete_binxcafdrivers

# Register binxcafdrivers in _BinXCAFDrivers:
_BinXCAFDrivers.binxcafdrivers_swigregister(binxcafdrivers)

def binxcafdrivers_AttributeDrivers(*args) -> "opencascade::handle< BinMDF_ADriverTable >":
    r"""
    Creates the table of drivers of types supported.

    Parameters
    ----------
    MsgDrv: Message_Messenger

    Returns
    -------
    opencascade::handle<BinMDF_ADriverTable>

    """
    return _BinXCAFDrivers.binxcafdrivers_AttributeDrivers(*args)

def binxcafdrivers_DefineFormat(*args) -> "void":
    r"""
    Defines format 'binxcaf' and registers its read and write drivers in the specified application.

    Parameters
    ----------
    theApp: TDocStd_Application

    Returns
    -------
    None

    """
    return _BinXCAFDrivers.binxcafdrivers_DefineFormat(*args)

def binxcafdrivers_Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
    r"""
    No available documentation.

    Parameters
    ----------
    theGUID: Standard_GUID

    Returns
    -------
    opencascade::handle<Standard_Transient>

    """
    return _BinXCAFDrivers.binxcafdrivers_Factory(*args)

class BinXCAFDrivers_DocumentRetrievalDriver(OCC.Core.BinDrivers.BinDrivers_DocumentRetrievalDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Returns
        -------
        None

        """
        _BinXCAFDrivers.BinXCAFDrivers_DocumentRetrievalDriver_swiginit(self, _BinXCAFDrivers.new_BinXCAFDrivers_DocumentRetrievalDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_BinXCAFDrivers_DocumentRetrievalDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinXCAFDrivers.delete_BinXCAFDrivers_DocumentRetrievalDriver

# Register BinXCAFDrivers_DocumentRetrievalDriver in _BinXCAFDrivers:
_BinXCAFDrivers.BinXCAFDrivers_DocumentRetrievalDriver_swigregister(BinXCAFDrivers_DocumentRetrievalDriver)

class BinXCAFDrivers_DocumentStorageDriver(OCC.Core.BinDrivers.BinDrivers_DocumentStorageDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Returns
        -------
        None

        """
        _BinXCAFDrivers.BinXCAFDrivers_DocumentStorageDriver_swiginit(self, _BinXCAFDrivers.new_BinXCAFDrivers_DocumentStorageDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_BinXCAFDrivers_DocumentStorageDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinXCAFDrivers.delete_BinXCAFDrivers_DocumentStorageDriver

# Register BinXCAFDrivers_DocumentStorageDriver in _BinXCAFDrivers:
_BinXCAFDrivers.BinXCAFDrivers_DocumentStorageDriver_swigregister(BinXCAFDrivers_DocumentStorageDriver)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.ShapeFix import *


class shapealgo:
	@staticmethod
	def AlgoContainer() -> ShapeAlgo_AlgoContainer: ...
	@staticmethod
	def Init() -> None: ...
	@staticmethod
	def SetAlgoContainer(aContainer: ShapeAlgo_AlgoContainer) -> None: ...

class ShapeAlgo_ToolContainer(Standard_Transient):
	def __init__(self) -> None: ...
	def EdgeProjAux(self) -> ShapeFix_EdgeProjAux: ...
	def FixShape(self) -> ShapeFix_Shape: ...

#classnotwrapped
class ShapeAlgo_AlgoContainer: ...

# harray1 classes
# harray2 classes
# hsequence classes

shapealgo_AlgoContainer = shapealgo.AlgoContainer
shapealgo_Init = shapealgo.Init
shapealgo_SetAlgoContainer = shapealgo.SetAlgoContainer



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *


class BRepProj_Projection:
	@overload
	def __init__(self, Wire: TopoDS_Shape, Shape: TopoDS_Shape, D: gp_Dir) -> None: ...
	@overload
	def __init__(self, Wire: TopoDS_Shape, Shape: TopoDS_Shape, P: gp_Pnt) -> None: ...
	def Current(self) -> TopoDS_Wire: ...
	def Init(self) -> None: ...
	def IsDone(self) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Shape(self) -> TopoDS_Compound: ...

# harray1 classes
# harray2 classes
# hsequence classes

